@@ -1,4 +1,4 @@
-# Copyright (c) 2019-2023, Jonas Eschle, Jim Pivarski, Eduardo Rodrigues, and Henry Schreiner.
+# Copyright (c) 2019-2024, Jonas Eschle, Jim Pivarski, Eduardo Rodrigues, and Henry Schreiner.
 #
 # Distributed under the 3-clause BSD license, see accompanying file LICENSE
 # or https://github.com/scikit-hep/vector for details.
@@ -32,7 +32,7 @@ from vector._methods import (
     Vector4D,
     dim,
 )
-from vector._version import __version__  # type: ignore[import-not-found]
+from vector._version import version as __version__
 from vector.backends.awkward_constructors import Array, zip
 from vector.backends.awkward_constructors import Array as awk
 from vector.backends.numpy import (
@@ -60,20 +60,13 @@ from vector.backends.object import (
 
 def _import_awkward() -> None:
     awk_version = packaging.version.Version(importlib.metadata.version("awkward"))
-    if awk_version < packaging.version.Version("1.2.0rc5"):
+    if awk_version < packaging.version.Version("2.0.0"):
         # the only context users will see this message is if they're trying to use vector.awk
         # VectorAwkward is still set to None
-        msg = f"awkward {awk_version} is too old; please upgrade to 1.2.0 or later"
+        msg = f"awkward {awk_version} is too old; please upgrade to 2.0.0 or later"
         raise ImportError(msg)
 
 
-_is_awkward_v2: bool | None
-try:
-    _is_awkward_v2 = packaging.version.Version(
-        importlib.metadata.version("awkward")
-    ) >= packaging.version.Version("2.0.0rc1")
-except importlib.metadata.PackageNotFoundError:
-    _is_awkward_v2 = None
 try:
     import awkward
 
@@ -83,7 +76,24 @@ except ImportError:
     if not typing.TYPE_CHECKING:
         VectorAwkward = None
 else:
-    from vector.backends.awkward import VectorAwkward
+    from vector.backends.awkward import VectorAwkward, awkward_transform
+
+try:
+    import sympy  # type: ignore[import-untyped]
+except ImportError:
+    sympy = None
+    if not typing.TYPE_CHECKING:
+        VectorSympy = None
+else:
+    from vector.backends.sympy import (
+        MomentumSympy2D,
+        MomentumSympy3D,
+        MomentumSympy4D,
+        VectorSympy,
+        VectorSympy2D,
+        VectorSympy3D,
+        VectorSympy4D,
+    )
 
 
 __all__: tuple[str, ...] = (
@@ -104,6 +114,9 @@ __all__: tuple[str, ...] = (
     "MomentumObject2D",
     "MomentumObject3D",
     "MomentumObject4D",
+    "MomentumSympy2D",
+    "MomentumSympy3D",
+    "MomentumSympy4D",
     "Planar",
     "Spatial",
     "Temporal",
@@ -122,15 +135,20 @@ __all__: tuple[str, ...] = (
     "VectorObject2D",
     "VectorObject3D",
     "VectorObject4D",
+    "VectorSympy",
+    "VectorSympy2D",
+    "VectorSympy3D",
+    "VectorSympy4D",
     "__version__",
     "arr",
     "array",
     "awk",
-    "zip",
+    "awkward_transform",
     "dim",
     "obj",
     "register_awkward",
     "register_numba",
+    "zip",
 )
 
 
