@@ -1,4 +1,4 @@
-# Copyright (c) 2019-2023, Jonas Eschle, Jim Pivarski, Eduardo Rodrigues, and Henry Schreiner.
+# Copyright (c) 2019-2024, Jonas Eschle, Jim Pivarski, Eduardo Rodrigues, and Henry Schreiner.
 #
 # Distributed under the 3-clause BSD license, see accompanying file LICENSE
 # or https://github.com/scikit-hep/vector for details.
@@ -9,6 +9,7 @@
     @property
     Lorentz.t(self)
 """
+
 from __future__ import annotations
 
 import typing
@@ -36,6 +37,9 @@ def xy_z_t(lib, x, y, z, t):
     return t
 
 
+xy_z_t.__awkward_transform_allowed__ = False  # type:ignore[attr-defined]
+
+
 def xy_z_tau(lib, x, y, z, tau):
     return lib.sqrt(t2.xy_z_tau(lib, x, y, z, tau))
 
@@ -44,6 +48,9 @@ def xy_theta_t(lib, x, y, theta, t):
     return t
 
 
+xy_theta_t.__awkward_transform_allowed__ = False  # type:ignore[attr-defined]
+
+
 def xy_theta_tau(lib, x, y, theta, tau):
     return lib.sqrt(t2.xy_theta_tau(lib, x, y, theta, tau))
 
@@ -52,6 +59,9 @@ def xy_eta_t(lib, x, y, eta, t):
     return t
 
 
+xy_eta_t.__awkward_transform_allowed__ = False  # type:ignore[attr-defined]
+
+
 def xy_eta_tau(lib, x, y, eta, tau):
     return lib.sqrt(t2.xy_eta_tau(lib, x, y, eta, tau))
 
@@ -60,6 +70,9 @@ def rhophi_z_t(lib, rho, phi, z, t):
     return t
 
 
+rhophi_z_t.__awkward_transform_allowed__ = False  # type:ignore[attr-defined]
+
+
 def rhophi_z_tau(lib, rho, phi, z, tau):
     return lib.sqrt(t2.rhophi_z_tau(lib, rho, phi, z, tau))
 
@@ -68,6 +81,9 @@ def rhophi_theta_t(lib, rho, phi, theta, t):
     return t
 
 
+rhophi_theta_t.__awkward_transform_allowed__ = False  # type:ignore[attr-defined]
+
+
 def rhophi_theta_tau(lib, rho, phi, theta, tau):
     return lib.sqrt(t2.rhophi_theta_tau(lib, rho, phi, theta, tau))
 
@@ -76,6 +92,9 @@ def rhophi_eta_t(lib, rho, phi, eta, t):
     return t
 
 
+rhophi_eta_t.__awkward_transform_allowed__ = False  # type:ignore[attr-defined]
+
+
 def rhophi_eta_tau(lib, rho, phi, eta, tau):
     return lib.sqrt(t2.rhophi_eta_tau(lib, rho, phi, eta, tau))
 
@@ -109,7 +128,7 @@ def dispatch(v: typing.Any) -> typing.Any:
     with numpy.errstate(all="ignore"):
         return v._wrap_result(
             _flavor_of(v),
-            function(
+            v._wrap_dispatched_function(function)(
                 v.lib,
                 *v.azimuthal.elements,
                 *v.longitudinal.elements,
