@@ -1,4 +1,4 @@
-# Copyright (c) 2019-2023, Jonas Eschle, Jim Pivarski, Eduardo Rodrigues, and Henry Schreiner.
+# Copyright (c) 2019-2024, Jonas Eschle, Jim Pivarski, Eduardo Rodrigues, and Henry Schreiner.
 #
 # Distributed under the 3-clause BSD license, see accompanying file LICENSE
 # or https://github.com/scikit-hep/vector for details.
@@ -9,6 +9,7 @@
     @property
     Lorentz.tau(self)
 """
+
 from __future__ import annotations
 
 import typing
@@ -41,6 +42,9 @@ def xy_z_tau(lib, x, y, z, tau):
     return tau
 
 
+xy_z_tau.__awkward_transform_allowed__ = False  # type:ignore[attr-defined]
+
+
 def xy_theta_t(lib, x, y, theta, t):
     squared = tau2.xy_theta_t(lib, x, y, theta, t)
     return lib.copysign(lib.sqrt(lib.absolute(squared)), squared)
@@ -50,6 +54,9 @@ def xy_theta_tau(lib, x, y, theta, tau):
     return tau
 
 
+xy_theta_tau.__awkward_transform_allowed__ = False  # type:ignore[attr-defined]
+
+
 def xy_eta_t(lib, x, y, eta, t):
     squared = tau2.xy_eta_t(lib, x, y, eta, t)
     return lib.copysign(lib.sqrt(lib.absolute(squared)), squared)
@@ -59,6 +66,9 @@ def xy_eta_tau(lib, x, y, eta, tau):
     return tau
 
 
+xy_eta_tau.__awkward_transform_allowed__ = False  # type:ignore[attr-defined]
+
+
 def rhophi_z_t(lib, rho, phi, z, t):
     squared = tau2.rhophi_z_t(lib, rho, phi, z, t)
     return lib.copysign(lib.sqrt(lib.absolute(squared)), squared)
@@ -68,6 +78,9 @@ def rhophi_z_tau(lib, rho, phi, z, tau):
     return tau
 
 
+rhophi_z_tau.__awkward_transform_allowed__ = False  # type:ignore[attr-defined]
+
+
 def rhophi_theta_t(lib, rho, phi, theta, t):
     squared = tau2.rhophi_theta_t(lib, rho, phi, theta, t)
     return lib.copysign(lib.sqrt(lib.absolute(squared)), squared)
@@ -77,6 +90,9 @@ def rhophi_theta_tau(lib, rho, phi, theta, tau):
     return tau
 
 
+rhophi_theta_tau.__awkward_transform_allowed__ = False  # type:ignore[attr-defined]
+
+
 def rhophi_eta_t(lib, rho, phi, eta, t):
     squared = tau2.rhophi_eta_t(lib, rho, phi, eta, t)
     return lib.copysign(lib.sqrt(lib.absolute(squared)), squared)
@@ -86,6 +102,9 @@ def rhophi_eta_tau(lib, rho, phi, eta, tau):
     return tau
 
 
+rhophi_eta_tau.__awkward_transform_allowed__ = False  # type:ignore[attr-defined]
+
+
 dispatch_map = {
     (AzimuthalXY, LongitudinalZ, TemporalT): (xy_z_t, float),
     (AzimuthalXY, LongitudinalZ, TemporalTau): (xy_z_tau, float),
@@ -115,7 +134,7 @@ def dispatch(v: typing.Any) -> typing.Any:
     with numpy.errstate(all="ignore"):
         return v._wrap_result(
             _flavor_of(v),
-            function(
+            v._wrap_dispatched_function(function)(
                 v.lib,
                 *v.azimuthal.elements,
                 *v.longitudinal.elements,
