@@ -1,4 +1,4 @@
-# Copyright (c) 2019-2023, Jonas Eschle, Jim Pivarski, Eduardo Rodrigues, and Henry Schreiner.
+# Copyright (c) 2019-2024, Jonas Eschle, Jim Pivarski, Eduardo Rodrigues, and Henry Schreiner.
 #
 # Distributed under the 3-clause BSD license, see accompanying file LICENSE
 # or https://github.com/scikit-hep/vector for details.
@@ -8,6 +8,7 @@
 
     Spatial.deltaangle(self, other)
 """
+
 from __future__ import annotations
 
 import typing
@@ -33,32 +34,61 @@ from vector._methods import (
 def xy_z_xy_z(lib, x1, y1, z1, x2, y2, z2):
     v1m = mag.xy_z(lib, x1, y1, z1)
     v2m = mag.xy_z(lib, x2, y2, z2)
-    return lib.arccos(dot.xy_z_xy_z(lib, x1, y1, z1, x2, y2, z2) / v1m / v2m)
+    return lib.arccos(
+        lib.maximum(
+            -1, lib.minimum(1, dot.xy_z_xy_z(lib, x1, y1, z1, x2, y2, z2) / v1m / v2m)
+        )
+    )
 
 
 def xy_z_xy_theta(lib, x1, y1, z1, x2, y2, theta2):
     v1m = mag.xy_z(lib, x1, y1, z1)
     v2m = mag.xy_theta(lib, x2, y2, theta2)
-    return lib.arccos(dot.xy_z_xy_theta(lib, x1, y1, z1, x2, y2, theta2) / v1m / v2m)
+    return lib.arccos(
+        lib.maximum(
+            -1,
+            lib.minimum(
+                1, dot.xy_z_xy_theta(lib, x1, y1, z1, x2, y2, theta2) / v1m / v2m
+            ),
+        )
+    )
 
 
 def xy_z_xy_eta(lib, x1, y1, z1, x2, y2, eta2):
     v1m = mag.xy_z(lib, x1, y1, z1)
     v2m = mag.xy_eta(lib, x2, y2, eta2)
-    return lib.arccos(dot.xy_z_xy_eta(lib, x1, y1, z1, x2, y2, eta2) / v1m / v2m)
+    return lib.arccos(
+        lib.maximum(
+            -1,
+            lib.minimum(1, dot.xy_z_xy_eta(lib, x1, y1, z1, x2, y2, eta2) / v1m / v2m),
+        )
+    )
 
 
 def xy_z_rhophi_z(lib, x1, y1, z1, rho2, phi2, z2):
     v1m = mag.xy_z(lib, x1, y1, z1)
     v2m = mag.rhophi_z(lib, rho2, phi2, z2)
-    return lib.arccos(dot.xy_z_rhophi_z(lib, x1, y1, z1, rho2, phi2, z2) / v1m / v2m)
+    return lib.arccos(
+        lib.maximum(
+            -1,
+            lib.minimum(
+                1, dot.xy_z_rhophi_z(lib, x1, y1, z1, rho2, phi2, z2) / v1m / v2m
+            ),
+        )
+    )
 
 
 def xy_z_rhophi_theta(lib, x1, y1, z1, rho2, phi2, theta2):
     v1m = mag.xy_z(lib, x1, y1, z1)
     v2m = mag.rhophi_theta(lib, rho2, phi2, theta2)
     return lib.arccos(
-        dot.xy_z_rhophi_theta(lib, x1, y1, z1, rho2, phi2, theta2) / v1m / v2m
+        lib.maximum(
+            -1,
+            lib.minimum(
+                1,
+                dot.xy_z_rhophi_theta(lib, x1, y1, z1, rho2, phi2, theta2) / v1m / v2m,
+            ),
+        )
     )
 
 
@@ -66,21 +96,39 @@ def xy_z_rhophi_eta(lib, x1, y1, z1, rho2, phi2, eta2):
     v1m = mag.xy_z(lib, x1, y1, z1)
     v2m = mag.rhophi_eta(lib, rho2, phi2, eta2)
     return lib.arccos(
-        dot.xy_z_rhophi_eta(lib, x1, y1, z1, rho2, phi2, eta2) / v1m / v2m
+        lib.maximum(
+            -1,
+            lib.minimum(
+                1, dot.xy_z_rhophi_eta(lib, x1, y1, z1, rho2, phi2, eta2) / v1m / v2m
+            ),
+        )
     )
 
 
 def xy_theta_xy_z(lib, x1, y1, theta1, x2, y2, z2):
     v1m = mag.xy_theta(lib, x1, y1, theta1)
     v2m = mag.xy_z(lib, x2, y2, z2)
-    return lib.arccos(dot.xy_theta_xy_z(lib, x1, y1, theta1, x2, y2, z2) / v1m / v2m)
+    return lib.arccos(
+        lib.maximum(
+            -1,
+            lib.minimum(
+                1, dot.xy_theta_xy_z(lib, x1, y1, theta1, x2, y2, z2) / v1m / v2m
+            ),
+        )
+    )
 
 
 def xy_theta_xy_theta(lib, x1, y1, theta1, x2, y2, theta2):
     v1m = mag.xy_theta(lib, x1, y1, theta1)
     v2m = mag.xy_theta(lib, x2, y2, theta2)
     return lib.arccos(
-        dot.xy_theta_xy_theta(lib, x1, y1, theta1, x2, y2, theta2) / v1m / v2m
+        lib.maximum(
+            -1,
+            lib.minimum(
+                1,
+                dot.xy_theta_xy_theta(lib, x1, y1, theta1, x2, y2, theta2) / v1m / v2m,
+            ),
+        )
     )
 
 
@@ -88,7 +136,12 @@ def xy_theta_xy_eta(lib, x1, y1, theta1, x2, y2, eta2):
     v1m = mag.xy_theta(lib, x1, y1, theta1)
     v2m = mag.xy_eta(lib, x2, y2, eta2)
     return lib.arccos(
-        dot.xy_theta_xy_eta(lib, x1, y1, theta1, x2, y2, eta2) / v1m / v2m
+        lib.maximum(
+            -1,
+            lib.minimum(
+                1, dot.xy_theta_xy_eta(lib, x1, y1, theta1, x2, y2, eta2) / v1m / v2m
+            ),
+        )
     )
 
 
@@ -96,7 +149,13 @@ def xy_theta_rhophi_z(lib, x1, y1, theta1, rho2, phi2, z2):
     v1m = mag.xy_theta(lib, x1, y1, theta1)
     v2m = mag.rhophi_z(lib, rho2, phi2, z2)
     return lib.arccos(
-        dot.xy_theta_rhophi_z(lib, x1, y1, theta1, rho2, phi2, z2) / v1m / v2m
+        lib.maximum(
+            -1,
+            lib.minimum(
+                1,
+                dot.xy_theta_rhophi_z(lib, x1, y1, theta1, rho2, phi2, z2) / v1m / v2m,
+            ),
+        )
     )
 
 
@@ -104,7 +163,15 @@ def xy_theta_rhophi_theta(lib, x1, y1, theta1, rho2, phi2, theta2):
     v1m = mag.xy_theta(lib, x1, y1, theta1)
     v2m = mag.rhophi_theta(lib, rho2, phi2, theta2)
     return lib.arccos(
-        dot.xy_theta_rhophi_theta(lib, x1, y1, theta1, rho2, phi2, theta2) / v1m / v2m
+        lib.maximum(
+            -1,
+            lib.minimum(
+                1,
+                dot.xy_theta_rhophi_theta(lib, x1, y1, theta1, rho2, phi2, theta2)
+                / v1m
+                / v2m,
+            ),
+        )
     )
 
 
@@ -112,35 +179,65 @@ def xy_theta_rhophi_eta(lib, x1, y1, theta1, rho2, phi2, eta2):
     v1m = mag.xy_theta(lib, x1, y1, theta1)
     v2m = mag.rhophi_eta(lib, rho2, phi2, eta2)
     return lib.arccos(
-        dot.xy_theta_rhophi_eta(lib, x1, y1, theta1, rho2, phi2, eta2) / v1m / v2m
+        lib.maximum(
+            -1,
+            lib.minimum(
+                1,
+                dot.xy_theta_rhophi_eta(lib, x1, y1, theta1, rho2, phi2, eta2)
+                / v1m
+                / v2m,
+            ),
+        )
     )
 
 
 def xy_eta_xy_z(lib, x1, y1, eta1, x2, y2, z2):
     v1m = mag.xy_eta(lib, x1, y1, eta1)
     v2m = mag.xy_z(lib, x2, y2, z2)
-    return lib.arccos(dot.xy_eta_xy_z(lib, x1, y1, eta1, x2, y2, z2) / v1m / v2m)
+    return lib.arccos(
+        lib.maximum(
+            -1,
+            lib.minimum(1, dot.xy_eta_xy_z(lib, x1, y1, eta1, x2, y2, z2) / v1m / v2m),
+        )
+    )
 
 
 def xy_eta_xy_theta(lib, x1, y1, eta1, x2, y2, theta2):
     v1m = mag.xy_eta(lib, x1, y1, eta1)
     v2m = mag.xy_theta(lib, x2, y2, theta2)
     return lib.arccos(
-        dot.xy_eta_xy_theta(lib, x1, y1, eta1, x2, y2, theta2) / v1m / v2m
+        lib.maximum(
+            -1,
+            lib.minimum(
+                1, dot.xy_eta_xy_theta(lib, x1, y1, eta1, x2, y2, theta2) / v1m / v2m
+            ),
+        )
     )
 
 
 def xy_eta_xy_eta(lib, x1, y1, eta1, x2, y2, eta2):
     v1m = mag.xy_eta(lib, x1, y1, eta1)
     v2m = mag.xy_eta(lib, x2, y2, eta2)
-    return lib.arccos(dot.xy_eta_xy_eta(lib, x1, y1, eta1, x2, y2, eta2) / v1m / v2m)
+    return lib.arccos(
+        lib.maximum(
+            -1,
+            lib.minimum(
+                1, dot.xy_eta_xy_eta(lib, x1, y1, eta1, x2, y2, eta2) / v1m / v2m
+            ),
+        )
+    )
 
 
 def xy_eta_rhophi_z(lib, x1, y1, eta1, rho2, phi2, z2):
     v1m = mag.xy_eta(lib, x1, y1, eta1)
     v2m = mag.rhophi_z(lib, rho2, phi2, z2)
     return lib.arccos(
-        dot.xy_eta_rhophi_z(lib, x1, y1, eta1, rho2, phi2, z2) / v1m / v2m
+        lib.maximum(
+            -1,
+            lib.minimum(
+                1, dot.xy_eta_rhophi_z(lib, x1, y1, eta1, rho2, phi2, z2) / v1m / v2m
+            ),
+        )
     )
 
 
@@ -148,7 +245,15 @@ def xy_eta_rhophi_theta(lib, x1, y1, eta1, rho2, phi2, theta2):
     v1m = mag.xy_eta(lib, x1, y1, eta1)
     v2m = mag.rhophi_theta(lib, rho2, phi2, theta2)
     return lib.arccos(
-        dot.xy_eta_rhophi_theta(lib, x1, y1, eta1, rho2, phi2, theta2) / v1m / v2m
+        lib.maximum(
+            -1,
+            lib.minimum(
+                1,
+                dot.xy_eta_rhophi_theta(lib, x1, y1, eta1, rho2, phi2, theta2)
+                / v1m
+                / v2m,
+            ),
+        )
     )
 
 
@@ -156,21 +261,40 @@ def xy_eta_rhophi_eta(lib, x1, y1, eta1, rho2, phi2, eta2):
     v1m = mag.xy_eta(lib, x1, y1, eta1)
     v2m = mag.rhophi_eta(lib, rho2, phi2, eta2)
     return lib.arccos(
-        dot.xy_eta_rhophi_eta(lib, x1, y1, eta1, rho2, phi2, eta2) / v1m / v2m
+        lib.maximum(
+            -1,
+            lib.minimum(
+                1,
+                dot.xy_eta_rhophi_eta(lib, x1, y1, eta1, rho2, phi2, eta2) / v1m / v2m,
+            ),
+        )
     )
 
 
 def rhophi_z_xy_z(lib, rho1, phi1, z1, x2, y2, z2):
     v1m = mag.rhophi_z(lib, rho1, phi1, z1)
     v2m = mag.xy_z(lib, x2, y2, z2)
-    return lib.arccos(dot.rhophi_z_xy_z(lib, rho1, phi1, z1, x2, y2, z2) / v1m / v2m)
+    return lib.arccos(
+        lib.maximum(
+            -1,
+            lib.minimum(
+                1, dot.rhophi_z_xy_z(lib, rho1, phi1, z1, x2, y2, z2) / v1m / v2m
+            ),
+        )
+    )
 
 
 def rhophi_z_xy_theta(lib, rho1, phi1, z1, x2, y2, theta2):
     v1m = mag.rhophi_z(lib, rho1, phi1, z1)
     v2m = mag.xy_theta(lib, x2, y2, theta2)
     return lib.arccos(
-        dot.rhophi_z_xy_theta(lib, rho1, phi1, z1, x2, y2, theta2) / v1m / v2m
+        lib.maximum(
+            -1,
+            lib.minimum(
+                1,
+                dot.rhophi_z_xy_theta(lib, rho1, phi1, z1, x2, y2, theta2) / v1m / v2m,
+            ),
+        )
     )
 
 
@@ -178,7 +302,12 @@ def rhophi_z_xy_eta(lib, rho1, phi1, z1, x2, y2, eta2):
     v1m = mag.rhophi_z(lib, rho1, phi1, z1)
     v2m = mag.xy_eta(lib, x2, y2, eta2)
     return lib.arccos(
-        dot.rhophi_z_xy_eta(lib, rho1, phi1, z1, x2, y2, eta2) / v1m / v2m
+        lib.maximum(
+            -1,
+            lib.minimum(
+                1, dot.rhophi_z_xy_eta(lib, rho1, phi1, z1, x2, y2, eta2) / v1m / v2m
+            ),
+        )
     )
 
 
@@ -186,7 +315,13 @@ def rhophi_z_rhophi_z(lib, rho1, phi1, z1, rho2, phi2, z2):
     v1m = mag.rhophi_z(lib, rho1, phi1, z1)
     v2m = mag.rhophi_z(lib, rho2, phi2, z2)
     return lib.arccos(
-        dot.rhophi_z_rhophi_z(lib, rho1, phi1, z1, rho2, phi2, z2) / v1m / v2m
+        lib.maximum(
+            -1,
+            lib.minimum(
+                1,
+                dot.rhophi_z_rhophi_z(lib, rho1, phi1, z1, rho2, phi2, z2) / v1m / v2m,
+            ),
+        )
     )
 
 
@@ -194,7 +329,15 @@ def rhophi_z_rhophi_theta(lib, rho1, phi1, z1, rho2, phi2, theta2):
     v1m = mag.rhophi_z(lib, rho1, phi1, z1)
     v2m = mag.rhophi_theta(lib, rho2, phi2, theta2)
     return lib.arccos(
-        dot.rhophi_z_rhophi_theta(lib, rho1, phi1, z1, rho2, phi2, theta2) / v1m / v2m
+        lib.maximum(
+            -1,
+            lib.minimum(
+                1,
+                dot.rhophi_z_rhophi_theta(lib, rho1, phi1, z1, rho2, phi2, theta2)
+                / v1m
+                / v2m,
+            ),
+        )
     )
 
 
@@ -202,7 +345,15 @@ def rhophi_z_rhophi_eta(lib, rho1, phi1, z1, rho2, phi2, eta2):
     v1m = mag.rhophi_z(lib, rho1, phi1, z1)
     v2m = mag.rhophi_eta(lib, rho2, phi2, eta2)
     return lib.arccos(
-        dot.rhophi_z_rhophi_eta(lib, rho1, phi1, z1, rho2, phi2, eta2) / v1m / v2m
+        lib.maximum(
+            -1,
+            lib.minimum(
+                1,
+                dot.rhophi_z_rhophi_eta(lib, rho1, phi1, z1, rho2, phi2, eta2)
+                / v1m
+                / v2m,
+            ),
+        )
     )
 
 
@@ -210,7 +361,13 @@ def rhophi_theta_xy_z(lib, rho1, phi1, theta1, x2, y2, z2):
     v1m = mag.rhophi_theta(lib, rho1, phi1, theta1)
     v2m = mag.xy_z(lib, x2, y2, z2)
     return lib.arccos(
-        dot.rhophi_theta_xy_z(lib, rho1, phi1, theta1, x2, y2, z2) / v1m / v2m
+        lib.maximum(
+            -1,
+            lib.minimum(
+                1,
+                dot.rhophi_theta_xy_z(lib, rho1, phi1, theta1, x2, y2, z2) / v1m / v2m,
+            ),
+        )
     )
 
 
@@ -218,7 +375,15 @@ def rhophi_theta_xy_theta(lib, rho1, phi1, theta1, x2, y2, theta2):
     v1m = mag.rhophi_theta(lib, rho1, phi1, theta1)
     v2m = mag.xy_theta(lib, x2, y2, theta2)
     return lib.arccos(
-        dot.rhophi_theta_xy_theta(lib, rho1, phi1, theta1, x2, y2, theta2) / v1m / v2m
+        lib.maximum(
+            -1,
+            lib.minimum(
+                1,
+                dot.rhophi_theta_xy_theta(lib, rho1, phi1, theta1, x2, y2, theta2)
+                / v1m
+                / v2m,
+            ),
+        )
     )
 
 
@@ -226,7 +391,15 @@ def rhophi_theta_xy_eta(lib, rho1, phi1, theta1, x2, y2, eta2):
     v1m = mag.rhophi_theta(lib, rho1, phi1, theta1)
     v2m = mag.xy_eta(lib, x2, y2, eta2)
     return lib.arccos(
-        dot.rhophi_theta_xy_eta(lib, rho1, phi1, theta1, x2, y2, eta2) / v1m / v2m
+        lib.maximum(
+            -1,
+            lib.minimum(
+                1,
+                dot.rhophi_theta_xy_eta(lib, rho1, phi1, theta1, x2, y2, eta2)
+                / v1m
+                / v2m,
+            ),
+        )
     )
 
 
@@ -234,7 +407,15 @@ def rhophi_theta_rhophi_z(lib, rho1, phi1, theta1, rho2, phi2, z2):
     v1m = mag.rhophi_theta(lib, rho1, phi1, theta1)
     v2m = mag.rhophi_z(lib, rho2, phi2, z2)
     return lib.arccos(
-        dot.rhophi_theta_rhophi_z(lib, rho1, phi1, theta1, rho2, phi2, z2) / v1m / v2m
+        lib.maximum(
+            -1,
+            lib.minimum(
+                1,
+                dot.rhophi_theta_rhophi_z(lib, rho1, phi1, theta1, rho2, phi2, z2)
+                / v1m
+                / v2m,
+            ),
+        )
     )
 
 
@@ -242,9 +423,17 @@ def rhophi_theta_rhophi_theta(lib, rho1, phi1, theta1, rho2, phi2, theta2):
     v1m = mag.rhophi_theta(lib, rho1, phi1, theta1)
     v2m = mag.rhophi_theta(lib, rho2, phi2, theta2)
     return lib.arccos(
-        dot.rhophi_theta_rhophi_theta(lib, rho1, phi1, theta1, rho2, phi2, theta2)
-        / v1m
-        / v2m
+        lib.maximum(
+            -1,
+            lib.minimum(
+                1,
+                dot.rhophi_theta_rhophi_theta(
+                    lib, rho1, phi1, theta1, rho2, phi2, theta2
+                )
+                / v1m
+                / v2m,
+            ),
+        )
     )
 
 
@@ -252,9 +441,15 @@ def rhophi_theta_rhophi_eta(lib, rho1, phi1, theta1, rho2, phi2, eta2):
     v1m = mag.rhophi_theta(lib, rho1, phi1, theta1)
     v2m = mag.rhophi_eta(lib, rho2, phi2, eta2)
     return lib.arccos(
-        dot.rhophi_theta_rhophi_eta(lib, rho1, phi1, theta1, rho2, phi2, eta2)
-        / v1m
-        / v2m
+        lib.maximum(
+            -1,
+            lib.minimum(
+                1,
+                dot.rhophi_theta_rhophi_eta(lib, rho1, phi1, theta1, rho2, phi2, eta2)
+                / v1m
+                / v2m,
+            ),
+        )
     )
 
 
@@ -262,7 +457,12 @@ def rhophi_eta_xy_z(lib, rho1, phi1, eta1, x2, y2, z2):
     v1m = mag.rhophi_eta(lib, rho1, phi1, eta1)
     v2m = mag.xy_z(lib, x2, y2, z2)
     return lib.arccos(
-        dot.rhophi_eta_xy_z(lib, rho1, phi1, eta1, x2, y2, z2) / v1m / v2m
+        lib.maximum(
+            -1,
+            lib.minimum(
+                1, dot.rhophi_eta_xy_z(lib, rho1, phi1, eta1, x2, y2, z2) / v1m / v2m
+            ),
+        )
     )
 
 
@@ -270,7 +470,15 @@ def rhophi_eta_xy_theta(lib, rho1, phi1, eta1, x2, y2, theta2):
     v1m = mag.rhophi_eta(lib, rho1, phi1, eta1)
     v2m = mag.xy_theta(lib, x2, y2, theta2)
     return lib.arccos(
-        dot.rhophi_eta_xy_theta(lib, rho1, phi1, eta1, x2, y2, theta2) / v1m / v2m
+        lib.maximum(
+            -1,
+            lib.minimum(
+                1,
+                dot.rhophi_eta_xy_theta(lib, rho1, phi1, eta1, x2, y2, theta2)
+                / v1m
+                / v2m,
+            ),
+        )
     )
 
 
@@ -278,7 +486,13 @@ def rhophi_eta_xy_eta(lib, rho1, phi1, eta1, x2, y2, eta2):
     v1m = mag.rhophi_eta(lib, rho1, phi1, eta1)
     v2m = mag.xy_eta(lib, x2, y2, eta2)
     return lib.arccos(
-        dot.rhophi_eta_xy_eta(lib, rho1, phi1, eta1, x2, y2, eta2) / v1m / v2m
+        lib.maximum(
+            -1,
+            lib.minimum(
+                1,
+                dot.rhophi_eta_xy_eta(lib, rho1, phi1, eta1, x2, y2, eta2) / v1m / v2m,
+            ),
+        )
     )
 
 
@@ -286,7 +500,15 @@ def rhophi_eta_rhophi_z(lib, rho1, phi1, eta1, rho2, phi2, z2):
     v1m = mag.rhophi_eta(lib, rho1, phi1, eta1)
     v2m = mag.rhophi_z(lib, rho2, phi2, z2)
     return lib.arccos(
-        dot.rhophi_eta_rhophi_z(lib, rho1, phi1, eta1, rho2, phi2, z2) / v1m / v2m
+        lib.maximum(
+            -1,
+            lib.minimum(
+                1,
+                dot.rhophi_eta_rhophi_z(lib, rho1, phi1, eta1, rho2, phi2, z2)
+                / v1m
+                / v2m,
+            ),
+        )
     )
 
 
@@ -294,9 +516,15 @@ def rhophi_eta_rhophi_theta(lib, rho1, phi1, eta1, rho2, phi2, theta2):
     v1m = mag.rhophi_eta(lib, rho1, phi1, eta1)
     v2m = mag.rhophi_theta(lib, rho2, phi2, theta2)
     return lib.arccos(
-        dot.rhophi_eta_rhophi_theta(lib, rho1, phi1, eta1, rho2, phi2, theta2)
-        / v1m
-        / v2m
+        lib.maximum(
+            -1,
+            lib.minimum(
+                1,
+                dot.rhophi_eta_rhophi_theta(lib, rho1, phi1, eta1, rho2, phi2, theta2)
+                / v1m
+                / v2m,
+            ),
+        )
     )
 
 
@@ -304,7 +532,15 @@ def rhophi_eta_rhophi_eta(lib, rho1, phi1, eta1, rho2, phi2, eta2):
     v1m = mag.rhophi_eta(lib, rho1, phi1, eta1)
     v2m = mag.rhophi_eta(lib, rho2, phi2, eta2)
     return lib.arccos(
-        dot.rhophi_eta_rhophi_eta(lib, rho1, phi1, eta1, rho2, phi2, eta2) / v1m / v2m
+        lib.maximum(
+            -1,
+            lib.minimum(
+                1,
+                dot.rhophi_eta_rhophi_eta(lib, rho1, phi1, eta1, rho2, phi2, eta2)
+                / v1m
+                / v2m,
+            ),
+        )
     )
 
 
@@ -459,9 +695,10 @@ def dispatch(v1: typing.Any, v2: typing.Any) -> typing.Any:
         ),
     )
     with numpy.errstate(all="ignore"):
-        return _handler_of(v1, v2)._wrap_result(
+        handler = _handler_of(v1, v2)
+        return handler._wrap_result(
             _flavor_of(v1, v2),
-            function(
+            handler._wrap_dispatched_function(function)(
                 _lib_of(v1, v2),
                 *v1.azimuthal.elements,
                 *v1.longitudinal.elements,
