@@ -1,4 +1,4 @@
-# Copyright (c) 2019-2023, Jonas Eschle, Jim Pivarski, Eduardo Rodrigues, and Henry Schreiner.
+# Copyright (c) 2019-2024, Jonas Eschle, Jim Pivarski, Eduardo Rodrigues, and Henry Schreiner.
 #
 # Distributed under the 3-clause BSD license, see accompanying file LICENSE
 # or https://github.com/scikit-hep/vector for details.
@@ -9,6 +9,7 @@
     @property
     Spatial.z(self)
 """
+
 from __future__ import annotations
 
 import typing
@@ -34,6 +35,9 @@ def xy_z(lib, x, y, z):
     return z
 
 
+xy_z.__awkward_transform_allowed__ = False  # type:ignore[attr-defined]
+
+
 def xy_theta(lib, x, y, theta):
     return lib.nan_to_num(
         rho.xy(lib, x, y) / lib.tan(theta), nan=0.0, posinf=inf, neginf=-inf
@@ -48,6 +52,9 @@ def rhophi_z(lib, rho, phi, z):
     return z
 
 
+rhophi_z.__awkward_transform_allowed__ = False  # type:ignore[attr-defined]
+
+
 def rhophi_theta(lib, rho, phi, theta):
     return lib.nan_to_num(rho / lib.tan(theta), nan=0.0, posinf=inf, neginf=-inf)
 
@@ -78,7 +85,9 @@ def dispatch(v: typing.Any) -> typing.Any:
     with numpy.errstate(all="ignore"):
         return v._wrap_result(
             _flavor_of(v),
-            function(v.lib, *v.azimuthal.elements, *v.longitudinal.elements),
+            v._wrap_dispatched_function(function)(
+                v.lib, *v.azimuthal.elements, *v.longitudinal.elements
+            ),
             returns,
             1,
         )
