@@ -1,4 +1,4 @@
-# Copyright (c) 2019-2023, Jonas Eschle, Jim Pivarski, Eduardo Rodrigues, and Henry Schreiner.
+# Copyright (c) 2019-2024, Jonas Eschle, Jim Pivarski, Eduardo Rodrigues, and Henry Schreiner.
 #
 # Distributed under the 3-clause BSD license, see accompanying file LICENSE
 # or https://github.com/scikit-hep/vector for details.
@@ -32,7 +32,9 @@ manages this non-strictness well.
 
 from __future__ import annotations
 
+import functools
 import numbers
+import operator
 import types
 import typing
 
@@ -82,10 +84,18 @@ from vector.backends.object import (
 vector._import_awkward()
 
 ArrayOrRecord = typing.TypeVar("ArrayOrRecord", bound=typing.Union[ak.Array, ak.Record])
+Array = typing.TypeVar("Array")
 
 behavior: typing.Any = {}
 
 
+def _touch(array: Array) -> Array:
+    # make sure that touching is only done on Awkward arrays
+    if isinstance(array, (ak.Array, ak.Record)) and ak.backend(array) == "typetracer":
+        return ak.typetracer.touch_data(array)
+    return array
+
+
 # coordinates classes are a formality for Awkward #############################
 
 
@@ -126,9 +136,9 @@ class AzimuthalAwkward(CoordinatesAwkward, Azimuthal):
         """
         fields = ak.fields(array)
         if "x" in fields and "y" in fields:
-            return AzimuthalAwkwardXY(array["x"], array["y"])
+            return AzimuthalAwkwardXY(_touch(array["x"]), _touch(array["y"]))
         elif "rho" in fields and "phi" in fields:
-            return AzimuthalAwkwardRhoPhi(array["rho"], array["phi"])
+            return AzimuthalAwkwardRhoPhi(_touch(array["rho"]), _touch(array["phi"]))
         else:
             raise ValueError(
                 "array does not have azimuthal coordinates (x, y or rho, phi): "
@@ -154,17 +164,17 @@ class AzimuthalAwkward(CoordinatesAwkward, Azimuthal):
         """
         fields = ak.fields(array)
         if "x" in fields and "y" in fields:
-            return AzimuthalAwkwardXY(array["x"], array["y"])
+            return AzimuthalAwkwardXY(_touch(array["x"]), _touch(array["y"]))
         elif "x" in fields and "py" in fields:
-            return AzimuthalAwkwardXY(array["x"], array["py"])
+            return AzimuthalAwkwardXY(_touch(array["x"]), _touch(array["py"]))
         elif "px" in fields and "y" in fields:
-            return AzimuthalAwkwardXY(array["px"], array["y"])
+            return AzimuthalAwkwardXY(_touch(array["px"]), _touch(array["y"]))
         elif "px" in fields and "py" in fields:
-            return AzimuthalAwkwardXY(array["px"], array["py"])
+            return AzimuthalAwkwardXY(_touch(array["px"]), _touch(array["py"]))
         elif "rho" in fields and "phi" in fields:
-            return AzimuthalAwkwardRhoPhi(array["rho"], array["phi"])
+            return AzimuthalAwkwardRhoPhi(_touch(array["rho"]), _touch(array["phi"]))
         elif "pt" in fields and "phi" in fields:
-            return AzimuthalAwkwardRhoPhi(array["pt"], array["phi"])
+            return AzimuthalAwkwardRhoPhi(_touch(array["pt"]), _touch(array["phi"]))
         else:
             raise ValueError(
                 "array does not have azimuthal coordinates (x/px, y/py or rho/pt, phi): "
@@ -206,11 +216,11 @@ class LongitudinalAwkward(CoordinatesAwkward, Longitudinal):
         """
         fields = ak.fields(array)
         if "z" in fields:
-            return LongitudinalAwkwardZ(array["z"])
+            return LongitudinalAwkwardZ(_touch(array["z"]))
         elif "theta" in fields:
-            return LongitudinalAwkwardTheta(array["theta"])
+            return LongitudinalAwkwardTheta(_touch(array["theta"]))
         elif "eta" in fields:
-            return LongitudinalAwkwardEta(array["eta"])
+            return LongitudinalAwkwardEta(_touch(array["eta"]))
         else:
             raise ValueError(
                 "array does not have longitudinal coordinates (z or theta or eta): "
@@ -237,13 +247,13 @@ class LongitudinalAwkward(CoordinatesAwkward, Longitudinal):
         """
         fields = ak.fields(array)
         if "z" in fields:
-            return LongitudinalAwkwardZ(array["z"])
+            return LongitudinalAwkwardZ(_touch(array["z"]))
         elif "pz" in fields:
-            return LongitudinalAwkwardZ(array["pz"])
+            return LongitudinalAwkwardZ(_touch(array["pz"]))
         elif "theta" in fields:
-            return LongitudinalAwkwardTheta(array["theta"])
+            return LongitudinalAwkwardTheta(_touch(array["theta"]))
         elif "eta" in fields:
-            return LongitudinalAwkwardEta(array["eta"])
+            return LongitudinalAwkwardEta(_touch(array["eta"]))
         else:
             raise ValueError(
                 "array does not have longitudinal coordinates (z/pz or theta or eta): "
@@ -284,9 +294,9 @@ class TemporalAwkward(CoordinatesAwkward, Temporal):
         """
         fields = ak.fields(array)
         if "t" in fields:
-            return TemporalAwkwardT(array["t"])
+            return TemporalAwkwardT(_touch(array["t"]))
         elif "tau" in fields:
-            return TemporalAwkwardTau(array["tau"])
+            return TemporalAwkwardTau(_touch(array["tau"]))
         else:
             raise ValueError(
                 "array does not have temporal coordinates (t or tau): "
@@ -312,21 +322,21 @@ class TemporalAwkward(CoordinatesAwkward, Temporal):
         """
         fields = ak.fields(array)
         if "t" in fields:
-            return TemporalAwkwardT(array["t"])
+            return TemporalAwkwardT(_touch(array["t"]))
         elif "E" in fields:
-            return TemporalAwkwardT(array["E"])
+            return TemporalAwkwardT(_touch(array["E"]))
         elif "e" in fields:
-            return TemporalAwkwardT(array["e"])
+            return TemporalAwkwardT(_touch(array["e"]))
         elif "energy" in fields:
-            return TemporalAwkwardT(array["energy"])
+            return TemporalAwkwardT(_touch(array["energy"]))
         elif "tau" in fields:
-            return TemporalAwkwardTau(array["tau"])
+            return TemporalAwkwardTau(_touch(array["tau"]))
         elif "M" in fields:
-            return TemporalAwkwardTau(array["M"])
+            return TemporalAwkwardTau(_touch(array["M"]))
         elif "m" in fields:
-            return TemporalAwkwardTau(array["m"])
+            return TemporalAwkwardTau(_touch(array["m"]))
         elif "mass" in fields:
-            return TemporalAwkwardTau(array["mass"])
+            return TemporalAwkwardTau(_touch(array["mass"]))
         else:
             raise ValueError(
                 "array does not have temporal coordinates (t/E/e/energy or tau/M/m/mass): "
@@ -384,7 +394,7 @@ class AzimuthalAwkwardRhoPhi(AzimuthalAwkward, AzimuthalRhoPhi):
         (<Array [[1, 2], None] type='2 * option[var * int64]'>, <Array [None, [1]] type='2 * option[var * int64]'>)
     """
 
-    __slots__ = ("rho", "phi")
+    __slots__ = ("phi", "rho")
 
     def __init__(self, rho: typing.Any, phi: typing.Any) -> None:
         self.rho = rho
@@ -609,14 +619,41 @@ def _no_record(x: ak.Array) -> ak.Array | None:
 
 # Type for mixing in Awkward later
 class AwkwardProtocol(Protocol):
-    def __getitem__(self, where: typing.Any) -> float | ak.Array | ak.Record | None:
-        ...
+    def __getitem__(self, where: typing.Any) -> float | ak.Array | ak.Record | None: ...
+
+
+class _lib(typing.NamedTuple):
+    """a wrapper that respects the numpy-like interface of awkward-array and the module interface of numpy"""
+
+    module: types.ModuleType
+    nplike: ak._nplikes.numpy_like.NumpyLike
+
+    def __eq__(self, other: typing.Any) -> bool:
+        if isinstance(other, _lib):
+            return self.module is other.module and self.nplike is other.nplike
+        else:
+            return self.module is other
+
+    def __ne__(self, other: typing.Any) -> bool:
+        return not self.__eq__(other)
+
+    def __getattr__(self, name: str) -> typing.Any:
+        if fun := getattr(self.nplike, name, False):
+            return fun
+        else:
+            return getattr(self.module, name)
 
 
 class VectorAwkward:
     """Mixin class for Awkward vectors."""
 
-    lib: types.ModuleType = numpy
+    @property
+    def lib(self):  # type:ignore[no-untyped-def]
+        if (
+            nplike := self.layout.backend.nplike  # type:ignore[attr-defined]
+        ) is ak._nplikes.typetracer.TypeTracer.instance():
+            return _lib(module=numpy, nplike=nplike)
+        return numpy
 
     def _wrap_result(
         self: AwkwardProtocol,
@@ -674,7 +711,13 @@ class VectorAwkward:
             fields = ak.fields(self)
             if num_vecargs == 1:
                 for name in fields:
-                    if name not in ("x", "y", "rho", "phi"):
+                    if name not in (
+                        "x",
+                        "y",
+                        "rho",
+                        "pt",
+                        "phi",
+                    ):
                         names.append(name)
                         arrays.append(self[name])
 
@@ -721,12 +764,20 @@ class VectorAwkward:
                         "x",
                         "y",
                         "rho",
+                        "pt",
                         "phi",
                         "z",
+                        "pz",
                         "theta",
                         "eta",
                         "t",
                         "tau",
+                        "m",
+                        "M",
+                        "mass",
+                        "e",
+                        "E",
+                        "energy",
                     ):
                         names.append(name)
                         arrays.append(self[name])
@@ -775,7 +826,17 @@ class VectorAwkward:
             fields = ak.fields(self)
             if num_vecargs == 1:
                 for name in fields:
-                    if name not in ("x", "y", "rho", "phi", "z", "theta", "eta"):
+                    if name not in (
+                        "x",
+                        "y",
+                        "rho",
+                        "pt",
+                        "phi",
+                        "z",
+                        "pz",
+                        "theta",
+                        "eta",
+                    ):
                         names.append(name)
                         arrays.append(self[name])
 
@@ -832,12 +893,20 @@ class VectorAwkward:
                         "x",
                         "y",
                         "rho",
+                        "pt",
                         "phi",
                         "z",
+                        "pz",
                         "theta",
                         "eta",
                         "t",
                         "tau",
+                        "m",
+                        "M",
+                        "mass",
+                        "e",
+                        "E",
+                        "energy",
                     ):
                         names.append(name)
                         arrays.append(self[name])
@@ -898,12 +967,20 @@ class VectorAwkward:
                         "x",
                         "y",
                         "rho",
+                        "pt",
                         "phi",
                         "z",
+                        "pz",
                         "theta",
                         "eta",
                         "t",
                         "tau",
+                        "m",
+                        "M",
+                        "mass",
+                        "e",
+                        "E",
+                        "energy",
                     ):
                         names.append(name)
                         arrays.append(self[name])
@@ -920,6 +997,105 @@ class VectorAwkward:
         else:
             raise AssertionError(repr(returns))
 
+    def _wrap_dispatched_function(
+        self: AwkwardProtocol,
+        func: typing.Callable,  # type: ignore[type-arg]
+    ) -> typing.Callable:  # type: ignore[type-arg]
+        return awkward_transform(func)
+
+
+_placeholder = object()
+
+
+class bind(functools.partial):  # type: ignore[type-arg]
+    def __call__(self, *args: typing.Any, **keywords: typing.Any) -> typing.Any:
+        keywords = {**self.keywords, **keywords}
+        iargs = iter(args)
+        args = tuple(next(iargs) if arg is _placeholder else arg for arg in self.args)
+        return self.func(*args, *iargs, **keywords)
+
+
+class awkward_transform:
+    """Apply a batch of transformations in a single layout traversal"""
+
+    def __init__(self, func: typing.Callable) -> None:  # type: ignore[type-arg]
+        self.func = func
+
+    def __call__(self, *args: typing.Any, **kwargs: typing.Any) -> typing.Callable:  # type: ignore[type-arg]
+        # '__awkward_transform_allowed__' is a flag that can be set to False to disable this wrapping, e.g. for no-ops
+        if not getattr(self.func, "__awkward_transform_allowed__", True):
+            return self.func(*args, **kwargs)
+
+        # only pos args
+        assert not kwargs
+
+        # prepare the function and its args; we're currently assuming non-nested input args
+        args2bind, awkward_arrays = [], []
+        n_orig_akarrays = 0
+        for arg in args:
+            if isinstance(arg, (ak.highlevel.Array, ak.highlevel.Record)):
+                n_orig_akarrays += 1
+                awkward_arrays.append(arg)
+                args2bind.append(_placeholder)
+            elif ak._regularize.is_array_like(arg):
+                awkward_arrays.append(ak.Array(ak.to_layout(arg)))
+                args2bind.append(_placeholder)
+            else:
+                args2bind.append(arg)
+
+        # this means we're working with awkward-arrays and we should group operations with ak.transform
+        if n_orig_akarrays > 0:
+
+            def transformer(
+                layouts: ak.contents.Content | tuple[ak.contents.Content, ...],
+                **kwargs: typing.Any,
+            ) -> ak.contents.Content:
+                if not isinstance(layouts, tuple):
+                    layouts = (layouts,)
+                if all(layout.is_numpy for layout in layouts):
+                    # setup parameter propagation, taken from awkward's broadcasting machinery
+                    options = kwargs["options"]
+                    rule = options.pop("broadcast_parameters_rule", None)
+                    try:
+                        parameters_factory = (
+                            ak._broadcasting.BROADCAST_RULE_TO_FACTORY_IMPL[rule]
+                        )
+                    except KeyError:
+                        raise ValueError(
+                            f"`broadcast_parameters_rule` should be one of {[str(x) for x in ak._broadcasting.BroadcastParameterRule]}, "
+                            f"but this routine received `{rule}`"
+                        ) from None
+
+                    # apply the function to the numpy arrays, first we need to 'partial out' all non-awkward array arguments
+                    out_numpys = bind(self.func, *args2bind)(
+                        *(map(operator.attrgetter("data"), layouts))
+                    )
+                    # if the function returns a single array, wrap it in a tuple
+                    if not isinstance(out_numpys, tuple):
+                        out_numpys = (out_numpys,)
+                    # propagate parameters
+                    out_params = parameters_factory(
+                        tuple(map(operator.attrgetter("parameters"), layouts)),
+                        len(out_numpys),
+                    )
+                    # wrap the numpy arrays in awkward arrays
+                    out_arrays = tuple(
+                        ak.contents.NumpyArray(data=data, parameters=parameters)
+                        for data, parameters in zip(out_numpys, out_params)
+                    )
+                    # if the function returns a single array, return it directly
+                    if len(out_arrays) == 1:
+                        return out_arrays[0]
+                    # return the awkward array(s)
+                    return out_arrays
+
+            # apply to all arrays
+            return ak.transform(transformer, *awkward_arrays)
+        # if we arrived here this is because we're not working with awkward arrays (or have awkward-array installed).
+        # that also means that if we call nested functions that are all decorated with this decorator, we'll end up here,
+        # which is great, because that still means only one awkward broadcasting traversal!
+        return self.func(*args, **kwargs)
+
 
 class VectorAwkward2D(VectorAwkward, Planar, Vector2D):
     """
@@ -1528,92 +1704,88 @@ VectorArray2D.ProjectionClass2D = VectorArray2D
 VectorArray2D.ProjectionClass3D = VectorArray3D
 VectorArray2D.ProjectionClass4D = VectorArray4D
 VectorArray2D.GenericClass = VectorArray2D
+VectorArray2D.MomentumClass = MomentumArray2D
 
 VectorRecord2D.ProjectionClass2D = VectorRecord2D
 VectorRecord2D.ProjectionClass3D = VectorRecord3D
 VectorRecord2D.ProjectionClass4D = VectorRecord4D
 VectorRecord2D.GenericClass = VectorRecord2D
+VectorRecord2D.MomentumClass = MomentumRecord2D
 
 MomentumArray2D.ProjectionClass2D = MomentumArray2D
 MomentumArray2D.ProjectionClass3D = MomentumArray3D
 MomentumArray2D.ProjectionClass4D = MomentumArray4D
 MomentumArray2D.GenericClass = VectorArray2D
+MomentumArray2D.MomentumClass = MomentumArray2D
 
 MomentumRecord2D.ProjectionClass2D = MomentumRecord2D
 MomentumRecord2D.ProjectionClass3D = MomentumRecord3D
 MomentumRecord2D.ProjectionClass4D = MomentumRecord4D
 MomentumRecord2D.GenericClass = VectorRecord2D
+MomentumRecord2D.MomentumClass = MomentumRecord2D
 
 VectorArray3D.ProjectionClass2D = VectorArray2D
 VectorArray3D.ProjectionClass3D = VectorArray3D
 VectorArray3D.ProjectionClass4D = VectorArray4D
 VectorArray3D.GenericClass = VectorArray3D
+VectorArray3D.MomentumClass = MomentumArray3D
 
 VectorRecord3D.ProjectionClass2D = VectorRecord2D
 VectorRecord3D.ProjectionClass3D = VectorRecord3D
 VectorRecord3D.ProjectionClass4D = VectorRecord4D
 VectorRecord3D.GenericClass = VectorRecord3D
+VectorRecord3D.MomentumClass = MomentumRecord3D
 
 MomentumArray3D.ProjectionClass2D = MomentumArray2D
 MomentumArray3D.ProjectionClass3D = MomentumArray3D
 MomentumArray3D.ProjectionClass4D = MomentumArray4D
 MomentumArray3D.GenericClass = VectorArray3D
+MomentumArray3D.MomentumClass = MomentumArray3D
 
 MomentumRecord3D.ProjectionClass2D = MomentumRecord2D
 MomentumRecord3D.ProjectionClass3D = MomentumRecord3D
 MomentumRecord3D.ProjectionClass4D = MomentumRecord4D
 MomentumRecord3D.GenericClass = VectorRecord3D
+MomentumRecord3D.MomentumClass = MomentumRecord3D
 
 VectorArray4D.ProjectionClass2D = VectorArray2D
 VectorArray4D.ProjectionClass3D = VectorArray3D
 VectorArray4D.ProjectionClass4D = VectorArray4D
 VectorArray4D.GenericClass = VectorArray4D
+VectorArray4D.MomentumClass = MomentumArray4D
 
 VectorRecord4D.ProjectionClass2D = VectorRecord2D
 VectorRecord4D.ProjectionClass3D = VectorRecord3D
 VectorRecord4D.ProjectionClass4D = VectorRecord4D
 VectorRecord4D.GenericClass = VectorRecord4D
+VectorRecord4D.MomentumClass = MomentumRecord4D
 
 MomentumArray4D.ProjectionClass2D = MomentumArray2D
 MomentumArray4D.ProjectionClass3D = MomentumArray3D
 MomentumArray4D.ProjectionClass4D = MomentumArray4D
 MomentumArray4D.GenericClass = VectorArray4D
+MomentumArray4D.MomentumClass = MomentumArray4D
 
 MomentumRecord4D.ProjectionClass2D = MomentumRecord2D
 MomentumRecord4D.ProjectionClass3D = MomentumRecord3D
 MomentumRecord4D.ProjectionClass4D = MomentumRecord4D
 MomentumRecord4D.GenericClass = VectorRecord4D
+MomentumRecord4D.MomentumClass = MomentumRecord4D
 
 
 # implementation of behaviors in Numba ########################################
 
-if vector._is_awkward_v2:
 
-    def _lookup_field(record_type: typing.Any, name: str) -> int:
-        return record_type.fields.index(name)
-
-else:
-
-    def _lookup_field(record_type: typing.Any, name: str) -> int:
-        return record_type.recordlookup.index(name)
+def _lookup_field(record_type: typing.Any, name: str) -> int:
+    return record_type.fields.index(name)
 
 
 def _arraytype_of(awkwardtype: typing.Any, component: str) -> typing.Any:
     import numba
 
-    if isinstance(
-        awkwardtype,
-        ak._connect.numba.layout.NumpyArrayType
-        if hasattr(ak._connect, "numba")  # Awkward v2
-        else ak._connect._numba.layout.NumpyArrayType,
-    ):
+    if isinstance(awkwardtype, ak._connect.numba.layout.NumpyArrayType):
         return awkwardtype.arraytype
-    elif isinstance(
-        awkwardtype,
-        ak._connect.numba.layout.IndexedArrayType
-        if hasattr(ak._connect, "numba")  # Awkward v2
-        else ak._connect._numba.layout.IndexedArrayType,
-    ):
+    elif isinstance(awkwardtype, ak._connect.numba.layout.IndexedArrayType):
         return _arraytype_of(awkwardtype.contenttype, component)
     raise numba.TypingError(
         f"vector components like {component!r} must be NumpyArrayType, not {awkwardtype}"
@@ -1691,9 +1863,11 @@ def _aztype_of(recordarraytype: typing.Any, is_momentum: bool) -> typing.Any:
 def _ltype_of(recordarraytype: typing.Any, is_momentum: bool) -> typing.Any:
     import numba
 
-    cls: type[LongitudinalObjectZ] | type[LongitudinalObjectTheta] | type[
-        LongitudinalObjectEta
-    ]
+    cls: (
+        type[LongitudinalObjectZ]
+        | type[LongitudinalObjectTheta]
+        | type[LongitudinalObjectEta]
+    )
 
     z_index = None
     theta_index = None
@@ -1894,11 +2068,7 @@ def _numba_lower(
 
     vectorcls = sig.return_type.instance_class
 
-    fields = (
-        sig.args[0].arrayviewtype.type.fields
-        if vector._is_awkward_v2
-        else sig.args[0].arrayviewtype.type.recordlookup
-    )
+    fields = sig.args[0].arrayviewtype.type.fields
 
     if issubclass(vectorcls, (VectorObject2D, VectorObject3D, VectorObject4D)):
         if issubclass(sig.return_type.azimuthaltype.instance_class, AzimuthalXY):
