@@ -1,4 +1,4 @@
-# Copyright (c) 2019-2023, Jonas Eschle, Jim Pivarski, Eduardo Rodrigues, and Henry Schreiner.
+# Copyright (c) 2019-2024, Jonas Eschle, Jim Pivarski, Eduardo Rodrigues, and Henry Schreiner.
 #
 # Distributed under the 3-clause BSD license, see accompanying file LICENSE
 # or https://github.com/scikit-hep/vector for details.
@@ -215,24 +215,38 @@ def _getitem(
             )
         if hasattr(array, "_longitudinal_type"):
             longitudinal = array._longitudinal_type.ObjectClass(
-                *(out[x] for x in _coordinate_class_to_names[_ltype(array)])  # type: ignore[arg-type]
+                *(out[x] for x in _coordinate_class_to_names[_ltype(array)])
             )
         if hasattr(array, "_temporal_type"):
             temporal = array._temporal_type.ObjectClass(
-                *(out[x] for x in _coordinate_class_to_names[_ttype(array)])  # type: ignore[arg-type]
+                *(out[x] for x in _coordinate_class_to_names[_ttype(array)])
             )
         if temporal is not None:
             return array.ObjectClass(
                 azimuthal=azimuthal,
-                longitudinal=longitudinal,  # type: ignore[arg-type, return-value]
+                longitudinal=longitudinal,  # type: ignore[arg-type]
                 temporal=temporal,  # type: ignore[arg-type]
             )
         elif longitudinal is not None:
-            return array.ObjectClass(azimuthal=azimuthal, longitudinal=longitudinal)  # type: ignore[arg-type, return-value]
+            return array.ObjectClass(azimuthal=azimuthal, longitudinal=longitudinal)  # type: ignore[arg-type]
         elif azimuthal is not None:
-            return array.ObjectClass(azimuthal=azimuthal)  # type: ignore[return-value]
+            return array.ObjectClass(azimuthal=azimuthal)
+        elif issubclass(array.ObjectClass, vector.backends.object.AzimuthalObject):
+            return array.ObjectClass(*tuple(out)[:2])  # type: ignore[arg-type]
+        elif issubclass(array.ObjectClass, vector.backends.object.LongitudinalObject):
+            coords = (
+                out.view(numpy.ndarray)[0]
+                if len(out) == 1  # type: ignore[arg-type]
+                else out.view(numpy.ndarray)[2]
+            )
+            return array.ObjectClass(coords)
         else:
-            return array.ObjectClass(*out.view(numpy.ndarray))  # type: ignore[misc, return-value]
+            coords = (
+                out.view(numpy.ndarray)[0]
+                if len(out) == 1  # type: ignore[arg-type]
+                else out.view(numpy.ndarray)[3]
+            )
+            return array.ObjectClass(coords)
 
 
 def _array_repr(
@@ -381,12 +395,10 @@ class GetItem:
     _IS_MOMENTUM: typing.ClassVar[bool]
 
     @typing.overload
-    def __getitem__(self, where: str) -> FloatArray:
-        ...
+    def __getitem__(self, where: str) -> FloatArray: ...
 
     @typing.overload
-    def __getitem__(self, where: typing.Any) -> float | FloatArray:
-        ...
+    def __getitem__(self, where: typing.Any) -> float | FloatArray: ...
 
     def __getitem__(self, where: typing.Any) -> float | FloatArray:
         return _getitem(self, where, self.__class__._IS_MOMENTUM)  # type: ignore[arg-type]
@@ -431,8 +443,13 @@ class AzimuthalNumpyXY(AzimuthalNumpy, AzimuthalXY, GetItem, FloatArray):  # typ
 
     ObjectClass = vector.backends.object.AzimuthalObjectXY
     _IS_MOMENTUM = False
+    dtype: numpy.dtype[typing.Any] = numpy.dtype(
+        [("x", numpy.float64), ("y", numpy.float64)]
+    )
 
     def __new__(cls, *args: typing.Any, **kwargs: typing.Any) -> AzimuthalNumpyXY:
+        if "dtype" in kwargs:
+            AzimuthalNumpyXY.dtype = numpy.dtype(kwargs["dtype"])
         return numpy.array(*args, **kwargs).view(cls)
 
     def __array_finalize__(self, obj: typing.Any) -> None:
@@ -442,6 +459,16 @@ class AzimuthalNumpyXY(AzimuthalNumpy, AzimuthalXY, GetItem, FloatArray):  # typ
                 'fields ("x", "y")'
             )
 
+    def __eq__(self, other: typing.Any) -> bool:
+        if self.dtype != other.dtype or not isinstance(other, AzimuthalNumpyXY):
+            return False
+        return all(coord1 == coord2 for coord1, coord2 in zip(self, other))
+
+    def __ne__(self, other: typing.Any) -> bool:
+        if self.dtype != other.dtype or not isinstance(other, AzimuthalNumpyXY):
+            return True
+        return any(coord1 != coord2 for coord1, coord2 in zip(self, other))
+
     @property
     def elements(self) -> tuple[FloatArray, FloatArray]:
         """
@@ -482,8 +509,13 @@ class AzimuthalNumpyRhoPhi(AzimuthalNumpy, AzimuthalRhoPhi, GetItem, FloatArray)
 
     ObjectClass = vector.backends.object.AzimuthalObjectRhoPhi
     _IS_MOMENTUM = False
+    dtype: numpy.dtype[typing.Any] = numpy.dtype(
+        [("rho", numpy.float64), ("phi", numpy.float64)]
+    )
 
     def __new__(cls, *args: typing.Any, **kwargs: typing.Any) -> AzimuthalNumpyRhoPhi:
+        if "dtype" in kwargs:
+            AzimuthalNumpyRhoPhi.dtype = numpy.dtype(kwargs["dtype"])
         return numpy.array(*args, **kwargs).view(cls)
 
     def __array_finalize__(self, obj: typing.Any) -> None:
@@ -493,6 +525,16 @@ class AzimuthalNumpyRhoPhi(AzimuthalNumpy, AzimuthalRhoPhi, GetItem, FloatArray)
                 'fields ("rho", "phi")'
             )
 
+    def __eq__(self, other: typing.Any) -> bool:
+        if self.dtype != other.dtype or not isinstance(other, AzimuthalNumpyRhoPhi):
+            return False
+        return all(coord1 == coord2 for coord1, coord2 in zip(self, other))
+
+    def __ne__(self, other: typing.Any) -> bool:
+        if self.dtype != other.dtype or not isinstance(other, AzimuthalNumpyRhoPhi):
+            return True
+        return any(coord1 != coord2 for coord1, coord2 in zip(self, other))
+
     @property
     def elements(self) -> tuple[FloatArray, FloatArray]:
         """
@@ -532,8 +574,11 @@ class LongitudinalNumpyZ(LongitudinalNumpy, LongitudinalZ, GetItem, FloatArray):
 
     ObjectClass = vector.backends.object.LongitudinalObjectZ
     _IS_MOMENTUM = False
+    dtype: numpy.dtype[typing.Any] = numpy.dtype([("z", numpy.float64)])
 
     def __new__(cls, *args: typing.Any, **kwargs: typing.Any) -> LongitudinalNumpyZ:
+        if "dtype" in kwargs:
+            LongitudinalNumpyZ.dtype = numpy.dtype(kwargs["dtype"])
         return numpy.array(*args, **kwargs).view(cls)
 
     def __array_finalize__(self, obj: typing.Any) -> None:
@@ -543,6 +588,16 @@ class LongitudinalNumpyZ(LongitudinalNumpy, LongitudinalZ, GetItem, FloatArray):
                 'field "z"'
             )
 
+    def __eq__(self, other: typing.Any) -> bool:
+        if self.dtype != other.dtype or not isinstance(other, LongitudinalNumpyZ):
+            return False
+        return all(coord1 == coord2 for coord1, coord2 in zip(self, other))
+
+    def __ne__(self, other: typing.Any) -> bool:
+        if self.dtype != other.dtype or not isinstance(other, LongitudinalNumpyZ):
+            return True
+        return any(coord1 != coord2 for coord1, coord2 in zip(self, other))
+
     @property
     def elements(self) -> tuple[FloatArray]:
         """
@@ -577,8 +632,11 @@ class LongitudinalNumpyTheta(LongitudinalNumpy, LongitudinalTheta, GetItem, Floa
 
     ObjectClass = vector.backends.object.LongitudinalObjectTheta
     _IS_MOMENTUM = False
+    dtype: numpy.dtype[typing.Any] = numpy.dtype([("theta", numpy.float64)])
 
     def __new__(cls, *args: typing.Any, **kwargs: typing.Any) -> LongitudinalNumpyTheta:
+        if "dtype" in kwargs:
+            LongitudinalNumpyTheta.dtype = numpy.dtype(kwargs["dtype"])
         return numpy.array(*args, **kwargs).view(cls)
 
     def __array_finalize__(self, obj: typing.Any) -> None:
@@ -588,6 +646,16 @@ class LongitudinalNumpyTheta(LongitudinalNumpy, LongitudinalTheta, GetItem, Floa
                 'field "theta"'
             )
 
+    def __eq__(self, other: typing.Any) -> bool:
+        if self.dtype != other.dtype or not isinstance(other, LongitudinalNumpyTheta):
+            return False
+        return all(coord1 == coord2 for coord1, coord2 in zip(self, other))
+
+    def __ne__(self, other: typing.Any) -> bool:
+        if self.dtype != other.dtype or not isinstance(other, LongitudinalNumpyTheta):
+            return True
+        return any(coord1 != coord2 for coord1, coord2 in zip(self, other))
+
     @property
     def elements(self) -> tuple[FloatArray]:
         """
@@ -622,8 +690,11 @@ class LongitudinalNumpyEta(LongitudinalNumpy, LongitudinalEta, GetItem, FloatArr
 
     ObjectClass = vector.backends.object.LongitudinalObjectEta
     _IS_MOMENTUM = False
+    dtype: numpy.dtype[typing.Any] = numpy.dtype([("eta", numpy.float64)])
 
     def __new__(cls, *args: typing.Any, **kwargs: typing.Any) -> LongitudinalNumpyEta:
+        if "dtype" in kwargs:
+            LongitudinalNumpyEta.dtype = numpy.dtype(kwargs["dtype"])
         return numpy.array(*args, **kwargs).view(cls)
 
     def __array_finalize__(self, obj: typing.Any) -> None:
@@ -633,6 +704,16 @@ class LongitudinalNumpyEta(LongitudinalNumpy, LongitudinalEta, GetItem, FloatArr
                 'field "eta"'
             )
 
+    def __eq__(self, other: typing.Any) -> bool:
+        if self.dtype != other.dtype or not isinstance(other, LongitudinalNumpyEta):
+            return False
+        return all(coord1 == coord2 for coord1, coord2 in zip(self, other))
+
+    def __ne__(self, other: typing.Any) -> bool:
+        if self.dtype != other.dtype or not isinstance(other, LongitudinalNumpyEta):
+            return True
+        return any(coord1 != coord2 for coord1, coord2 in zip(self, other))
+
     @property
     def elements(self) -> tuple[FloatArray]:
         """
@@ -667,8 +748,11 @@ class TemporalNumpyT(TemporalNumpy, TemporalT, GetItem, FloatArray):  # type: ig
 
     ObjectClass = vector.backends.object.TemporalObjectT
     _IS_MOMENTUM = False
+    dtype: numpy.dtype[typing.Any] = numpy.dtype([("t", numpy.float64)])
 
     def __new__(cls, *args: typing.Any, **kwargs: typing.Any) -> TemporalNumpyT:
+        if "dtype" in kwargs:
+            TemporalNumpyT.dtype = numpy.dtype(kwargs["dtype"])
         return numpy.array(*args, **kwargs).view(cls)
 
     def __array_finalize__(self, obj: typing.Any) -> None:
@@ -678,6 +762,16 @@ class TemporalNumpyT(TemporalNumpy, TemporalT, GetItem, FloatArray):  # type: ig
                 'field "t"'
             )
 
+    def __eq__(self, other: typing.Any) -> bool:
+        if self.dtype != other.dtype or not isinstance(other, TemporalNumpyT):
+            return False
+        return all(coord1 == coord2 for coord1, coord2 in zip(self, other))
+
+    def __ne__(self, other: typing.Any) -> bool:
+        if self.dtype != other.dtype or not isinstance(other, TemporalNumpyT):
+            return True
+        return any(coord1 != coord2 for coord1, coord2 in zip(self, other))
+
     @property
     def elements(self) -> tuple[FloatArray]:
         """
@@ -704,8 +798,11 @@ class TemporalNumpyTau(TemporalNumpy, TemporalTau, GetItem, FloatArray):  # type
 
     ObjectClass = vector.backends.object.TemporalObjectTau
     _IS_MOMENTUM = False
+    dtype: numpy.dtype[typing.Any] = numpy.dtype([("tau", numpy.float64)])
 
     def __new__(cls, *args: typing.Any, **kwargs: typing.Any) -> TemporalNumpyTau:
+        if "dtype" in kwargs:
+            TemporalNumpyTau.dtype = numpy.dtype(kwargs["dtype"])
         return numpy.array(*args, **kwargs).view(cls)
 
     def __array_finalize__(self, obj: typing.Any) -> None:
@@ -715,6 +812,16 @@ class TemporalNumpyTau(TemporalNumpy, TemporalTau, GetItem, FloatArray):  # type
                 'field "tau"'
             )
 
+    def __eq__(self, other: typing.Any) -> bool:
+        if self.dtype != other.dtype or not isinstance(other, TemporalNumpyTau):
+            return False
+        return all(coord1 == coord2 for coord1, coord2 in zip(self, other))
+
+    def __ne__(self, other: typing.Any) -> bool:
+        if self.dtype != other.dtype or not isinstance(other, TemporalNumpyTau):
+            return True
+        return any(coord1 != coord2 for coord1, coord2 in zip(self, other))
+
     @property
     def elements(self) -> tuple[FloatArray]:
         """
@@ -763,7 +870,6 @@ class VectorNumpy(Vector, GetItem):
     ) -> SameVectorNumpyType:
         return typing.cast(
             SameVectorNumpyType,
-            # pylint: disable-next=unexpected-keyword-arg
             numpy.sum(
                 self,
                 axis=axis,
@@ -772,14 +878,14 @@ class VectorNumpy(Vector, GetItem):
                 keepdims=keepdims,
                 initial=initial,
                 where=where,
-            ),  # type: ignore[call-overload]
+            ),
         )
 
     def __eq__(self, other: typing.Any) -> typing.Any:
-        return numpy.equal(self, other)  # type: ignore[call-overload]
+        return numpy.equal(self, other)
 
     def __ne__(self, other: typing.Any) -> typing.Any:
-        return numpy.not_equal(self, other)  # type: ignore[call-overload]
+        return numpy.not_equal(self, other)
 
     def __reduce__(self) -> str | tuple[typing.Any, ...]:
         pickled_state = super().__reduce__()
@@ -1037,6 +1143,14 @@ class VectorNumpy2D(VectorNumpy, Planar, Vector2D, FloatArray):  # type: ignore[
         >>> vec
         VectorNumpy2D([(1.1, 2.1), (1.2, 2.2), (1.3, 2.3), (1.4, 2.4), (1.5, 2.5)],
                       dtype=[('x', '<f8'), ('y', '<f8')])
+
+        >>> import numpy as np
+        >>> import vector
+        >>> arr = np.array([(1.1, 2.1), (1.2, 2.2), (1.3, 2.3), (1.4, 2.4), (1.5, 2.5)],
+        ...               dtype=[('x', float), ('y', float)])
+        >>> arr.view(vector.VectorNumpy2D)
+        VectorNumpy2D([(1.1, 2.1), (1.2, 2.2), (1.3, 2.3), (1.4, 2.4), (1.5, 2.5)],
+                      dtype=[('x', '<f8'), ('y', '<f8')])
     """
 
     ObjectClass = vector.backends.object.VectorObject2D
@@ -1090,7 +1204,7 @@ class VectorNumpy2D(VectorNumpy, Planar, Vector2D, FloatArray):  # type: ignore[
             AzimuthalNumpyXY([(1.1, 2.1), (1.2, 2.2), (1.3, 2.3), (1.4, 2.4),
                               (1.5, 2.5)], dtype=[('x', '<f8'), ('y', '<f8')])
         """
-        return self.view(self._azimuthal_type)  # type: ignore[return-value]
+        return self.view(self._azimuthal_type)
 
     def _wrap_result(
         self,
@@ -1114,9 +1228,8 @@ class VectorNumpy2D(VectorNumpy, Planar, Vector2D, FloatArray):  # type: ignore[
         if returns in ([float], [bool]):
             return result
 
-        elif (
-            len(returns) == 1
-            or (len(returns) == 2 and returns[1] is None)
+        elif len(returns) == 1 or (
+            (len(returns) == 2 and returns[1] is None)
             and isinstance(returns[0], type)
             and issubclass(returns[0], Azimuthal)
         ):
@@ -1194,11 +1307,14 @@ class VectorNumpy2D(VectorNumpy, Planar, Vector2D, FloatArray):  # type: ignore[
         else:
             raise AssertionError(repr(returns))
 
+    def _wrap_dispatched_function(self, func: typing.Callable) -> typing.Callable:  # type: ignore[type-arg]
+        return func
+
     def __setitem__(self, where: typing.Any, what: typing.Any) -> None:
         return _setitem(self, where, what, False)
 
 
-class MomentumNumpy2D(PlanarMomentum, VectorNumpy2D):  # type: ignore[misc]
+class MomentumNumpy2D(PlanarMomentum, VectorNumpy2D):
     """
     Two dimensional momentum vector class for the NumPy backend. This class can be directly
     used to construct two dimensional NumPy momentum vectors. For two dimensional
@@ -1211,6 +1327,14 @@ class MomentumNumpy2D(PlanarMomentum, VectorNumpy2D):  # type: ignore[misc]
         >>> vec
         MomentumNumpy2D([(1.1, 2.1), (1.2, 2.2), (1.3, 2.3), (1.4, 2.4), (1.5, 2.5)],
                         dtype=[('x', '<f8'), ('y', '<f8')])
+
+        >>> import numpy as np
+        >>> import vector
+        >>> arr = np.array([(1.1, 2.1), (1.2, 2.2), (1.3, 2.3), (1.4, 2.4), (1.5, 2.5)],
+        ...               dtype=[('px', float), ('py', float)])
+        >>> arr.view(vector.MomentumNumpy2D)
+        MomentumNumpy2D([(1.1, 2.1), (1.2, 2.2), (1.3, 2.3), (1.4, 2.4), (1.5, 2.5)],
+                        dtype=[('x', '<f8'), ('y', '<f8')])
     """
 
     ObjectClass = vector.backends.object.MomentumObject2D
@@ -1260,15 +1384,25 @@ class VectorNumpy3D(VectorNumpy, Spatial, Vector3D, FloatArray):  # type: ignore
         >>> vec
         VectorNumpy3D([(1.1, 2.1, 3.1), (1.2, 2.2, 3.2), (1.3, 2.3, 3.3), (1.4, 2.4, 3.4),
                        (1.5, 2.5, 3.5)], dtype=[('x', '<f8'), ('y', '<f8'), ('z', '<f8')])
+
+        >>> import numpy as np
+        >>> import vector
+        >>> arr = np.array([(1.1, 2.1, 3.1), (1.2, 2.2, 3.2), (1.3, 2.3, 3.3), (1.4, 2.4, 3.4), (1.5, 2.5, 3.5)],
+        ...               dtype=[('x', float), ('y', float), ('z', float)])
+        >>> arr.view(vector.VectorNumpy3D)
+        VectorNumpy3D([(1.1, 2.1, 3.1), (1.2, 2.2, 3.2), (1.3, 2.3, 3.3), (1.4, 2.4, 3.4),
+                       (1.5, 2.5, 3.5)], dtype=[('x', '<f8'), ('y', '<f8'), ('z', '<f8')])
     """
 
     ObjectClass = vector.backends.object.VectorObject3D
     _IS_MOMENTUM = False
 
     _azimuthal_type: type[AzimuthalNumpyXY] | type[AzimuthalNumpyRhoPhi]
-    _longitudinal_type: type[LongitudinalNumpyZ] | type[LongitudinalNumpyTheta] | type[
-        LongitudinalNumpyEta
-    ]
+    _longitudinal_type: (
+        type[LongitudinalNumpyZ]
+        | type[LongitudinalNumpyTheta]
+        | type[LongitudinalNumpyEta]
+    )
 
     def __new__(cls, *args: typing.Any, **kwargs: typing.Any) -> VectorNumpy3D:
         """Returns the object of ``VectorNumpy3D``. Behaves as ``__init__`` in this case."""
@@ -1316,15 +1450,47 @@ class VectorNumpy3D(VectorNumpy, Spatial, Vector3D, FloatArray):  # type: ignore
 
     @property
     def azimuthal(self) -> AzimuthalNumpy:
-        """Returns the azimuthal type class for the given ``VectorNumpy3D`` object."""
-        # TODO: Add an example here - see https://github.com/scikit-hep/vector/issues/194
-        return self.view(self._azimuthal_type)  # type: ignore[return-value]
+        """
+        Returns the azimuthal type class for the given ``VectorNumpy3D`` object.
+
+        Example:
+            >>> import vector
+            >>> vec = vector.array(
+            ... [
+            ...     (1.1, 2.1, 3.1),
+            ...     (1.2, 2.2, 3.2),
+            ...     (1.3, 2.3, 3.3),
+            ...     (1.4, 2.4, 4.4),
+            ...     (1.5, 2.5, 5.5)
+            ...    ], dtype=[("x", float), ("y", float), ("z", float)]
+            ... )
+            >>> vec.azimuthal
+            AzimuthalNumpyXY([(1.1, 2.1), (1.2, 2.2), (1.3, 2.3), (1.4, 2.4),
+                  (1.5, 2.5)], dtype=[('x', '<f8'), ('y', '<f8')])
+        """
+        return self.view(self._azimuthal_type)
 
     @property
     def longitudinal(self) -> LongitudinalNumpy:
-        """Returns the longitudinal type class for the given ``VectorNumpy3D`` object."""
-        # TODO: Add an example here - see https://github.com/scikit-hep/vector/issues/194
-        return self.view(self._longitudinal_type)  # type: ignore[return-value]
+        """
+        Returns the longitudinal type class for the given ``VectorNumpy3D`` object.
+
+        Example:
+            >>> import vector
+            >>> vec = vector.array(
+            ... [
+            ...     (1.1, 2.1, 3.1),
+            ...     (1.2, 2.2, 3.2),
+            ...     (1.3, 2.3, 3.3),
+            ...     (1.4, 2.4, 4.4),
+            ...     (1.5, 2.5, 5.5)
+            ...    ], dtype=[("x", float), ("y", float), ("z", float)]
+            ... )
+            >>> vec.longitudinal
+            LongitudinalNumpyZ([(3.1,), (3.2,), (3.3,), (4.4,), (5.5,)],
+                   dtype=[('z', '<f8')])
+        """
+        return self.view(self._longitudinal_type)
 
     def _wrap_result(
         self,
@@ -1385,9 +1551,8 @@ class VectorNumpy3D(VectorNumpy, Spatial, Vector3D, FloatArray):  # type: ignore
                 out[name] = result[i]
             return out.view(cls.ProjectionClass2D)
 
-        elif (
-            len(returns) == 2
-            or (len(returns) == 3 and returns[2] is None)
+        elif len(returns) == 2 or (
+            (len(returns) == 3 and returns[2] is None)
             and isinstance(returns[0], type)
             and issubclass(returns[0], Azimuthal)
             and isinstance(returns[1], type)
@@ -1449,11 +1614,14 @@ class VectorNumpy3D(VectorNumpy, Spatial, Vector3D, FloatArray):  # type: ignore
         else:
             raise AssertionError(repr(returns))
 
+    def _wrap_dispatched_function(self, func: typing.Callable) -> typing.Callable:  # type: ignore[type-arg]
+        return func
+
     def __setitem__(self, where: typing.Any, what: typing.Any) -> None:
         return _setitem(self, where, what, False)
 
 
-class MomentumNumpy3D(SpatialMomentum, VectorNumpy3D):  # type: ignore[misc]
+class MomentumNumpy3D(SpatialMomentum, VectorNumpy3D):
     """
     Three dimensional momentum vector class for the NumPy backend. This class can be directly
     used to construct three dimensional NumPy momentum vectors. For three dimensional
@@ -1466,6 +1634,14 @@ class MomentumNumpy3D(SpatialMomentum, VectorNumpy3D):  # type: ignore[misc]
         >>> vec
         MomentumNumpy3D([(1.1, 2.1, 3.1), (1.2, 2.2, 3.2), (1.3, 2.3, 3.3), (1.4, 2.4, 3.4),
                          (1.5, 2.5, 3.5)], dtype=[('x', '<f8'), ('y', '<f8'), ('z', '<f8')])
+
+        >>> import numpy as np
+        >>> import vector
+        >>> arr = np.array([(1.1, 2.1, 3.1), (1.2, 2.2, 3.2), (1.3, 2.3, 3.3), (1.4, 2.4, 3.4), (1.5, 2.5, 3.5)],
+        ...               dtype=[('px', float), ('py', float), ('pz', float)])
+        >>> arr.view(vector.MomentumNumpy3D)
+        MomentumNumpy3D([(1.1, 2.1, 3.1), (1.2, 2.2, 3.2), (1.3, 2.3, 3.3), (1.4, 2.4, 3.4),
+                         (1.5, 2.5, 3.5)], dtype=[('x', '<f8'), ('y', '<f8'), ('z', '<f8')])
     """
 
     ObjectClass = vector.backends.object.MomentumObject3D
@@ -1526,15 +1702,26 @@ class VectorNumpy4D(VectorNumpy, Lorentz, Vector4D, FloatArray):  # type: ignore
         VectorNumpy4D([(1.1, 2.1, 3.1, 4.1), (1.2, 2.2, 3.2, 4.2), (1.3, 2.3, 3.3, 4.3),
                        (1.4, 2.4, 3.4, 4.4), (1.5, 2.5, 3.5, 4.5)],
                       dtype=[('x', '<f8'), ('y', '<f8'), ('z', '<f8'), ('t', '<f8')])
+
+        >>> import numpy as np
+        >>> import vector
+        >>> arr = np.array([(1.1, 2.1, 3.1, 4.1), (1.2, 2.2, 3.2, 4.2), (1.3, 2.3, 3.3, 4.3), (1.4, 2.4, 3.4, 4.4), (1.5, 2.5, 3.5, 4.5)],
+        ...               dtype=[('x', float), ('y', float), ('z', float), ('t', float)])
+        >>> arr.view(vector.VectorNumpy4D)
+        VectorNumpy4D([(1.1, 2.1, 3.1, 4.1), (1.2, 2.2, 3.2, 4.2), (1.3, 2.3, 3.3, 4.3),
+                       (1.4, 2.4, 3.4, 4.4), (1.5, 2.5, 3.5, 4.5)],
+                      dtype=[('x', '<f8'), ('y', '<f8'), ('z', '<f8'), ('t', '<f8')])
     """
 
     ObjectClass = vector.backends.object.VectorObject4D
     _IS_MOMENTUM = False
 
     _azimuthal_type: type[AzimuthalNumpyXY] | type[AzimuthalNumpyRhoPhi]
-    _longitudinal_type: type[LongitudinalNumpyZ] | type[LongitudinalNumpyTheta] | type[
-        LongitudinalNumpyEta
-    ]
+    _longitudinal_type: (
+        type[LongitudinalNumpyZ]
+        | type[LongitudinalNumpyTheta]
+        | type[LongitudinalNumpyEta]
+    )
     _temporal_type: type[TemporalNumpyT] | type[TemporalNumpyTau]
 
     def __new__(cls, *args: typing.Any, **kwargs: typing.Any) -> VectorNumpy4D:
@@ -1594,21 +1781,68 @@ class VectorNumpy4D(VectorNumpy, Lorentz, Vector4D, FloatArray):  # type: ignore
 
     @property
     def azimuthal(self) -> AzimuthalNumpy:
-        """Returns the azimuthal type class for the given ``VectorNumpy4D`` object."""
-        # TODO: Add an example here - see https://github.com/scikit-hep/vector/issues/194
-        return self.view(self._azimuthal_type)  # type: ignore[return-value]
+        """
+        Returns the azimuthal type class for the given ``VectorNumpy4D`` object.
+
+        Example:
+            >>> import vector
+            >>> vec = vector.array(
+            ... [
+            ...     (1.1, 2.1, 3.1, 4.1),
+            ...     (1.2, 2.2, 3.2, 4.2),
+            ...     (1.3, 2.3, 3.3, 4.3),
+            ...     (1.4, 2.4, 3.4, 4.4),
+            ...     (1.5, 2.5, 3.5, 4.5)
+            ... ], dtype=[("x", float), ("y", float), ("z", float), ("t", float)]
+            ... )
+            >>> vec.azimuthal
+            AzimuthalNumpyXY([(1.1, 2.1), (1.2, 2.2), (1.3, 2.3), (1.4, 2.4),
+                  (1.5, 2.5)], dtype=[('x', '<f8'), ('y', '<f8')])
+        """
+        return self.view(self._azimuthal_type)
 
     @property
     def longitudinal(self) -> LongitudinalNumpy:
-        """Returns the longitudinal type class for the given ``Vectornumpy4D`` object."""
-        # TODO: Add an example here - see https://github.com/scikit-hep/vector/issues/194
-        return self.view(self._longitudinal_type)  # type: ignore[return-value]
+        """
+        Returns the longitudinal type class for the given ``VectorNumpy4D`` object.
+
+        Example:
+            >>> import vector
+            >>> vec = vector.array(
+            ... [
+            ...     (1.1, 2.1, 3.1, 4.1),
+            ...     (1.2, 2.2, 3.2, 4.2),
+            ...     (1.3, 2.3, 3.3, 4.3),
+            ...     (1.4, 2.4, 3.4, 4.4),
+            ...     (1.5, 2.5, 3.5, 4.5)
+            ... ], dtype=[("x", float), ("y", float), ("z", float), ("t", float)]
+            ... )
+            >>> vec.longitudinal
+            LongitudinalNumpyZ([(3.1,), (3.2,), (3.3,), (3.4,), (3.5,)],
+                   dtype=[('z', '<f8')])
+        """
+        return self.view(self._longitudinal_type)
 
     @property
     def temporal(self) -> TemporalNumpy:
-        """Returns the azimuthal type class for the given ``VectorNumpy4D`` object."""
-        # TODO: Add an example here - see https://github.com/scikit-hep/vector/issues/194
-        return self.view(self._temporal_type)  # type: ignore[return-value]
+        """
+        Returns the temporal type class for the given ``VectorNumpy4D`` object.
+
+        Example:
+            >>> import vector
+            >>> vec = vector.array(
+            ... [
+            ...     (1.1, 2.1, 3.1, 4.1),
+            ...     (1.2, 2.2, 3.2, 4.2),
+            ...     (1.3, 2.3, 3.3, 4.3),
+            ...     (1.4, 2.4, 3.4, 4.4)
+            ... ], dtype=[("x", float), ("y", float), ("z", float), ("t", float)]
+            ... )
+            >>> vec.temporal
+            TemporalNumpyT([(4.1,), (4.2,), (4.3,), (4.4,)],
+                   dtype=[('t', '<f8')])
+        """
+        return self.view(self._temporal_type)
 
     def _wrap_result(
         self,
@@ -1767,11 +2001,14 @@ class VectorNumpy4D(VectorNumpy, Lorentz, Vector4D, FloatArray):  # type: ignore
         else:
             raise AssertionError(repr(returns))
 
+    def _wrap_dispatched_function(self, func: typing.Callable) -> typing.Callable:  # type: ignore[type-arg]
+        return func
+
     def __setitem__(self, where: typing.Any, what: typing.Any) -> None:
         return _setitem(self, where, what, False)
 
 
-class MomentumNumpy4D(LorentzMomentum, VectorNumpy4D):  # type: ignore[misc]
+class MomentumNumpy4D(LorentzMomentum, VectorNumpy4D):
     """
     Four dimensional momentum vector class for the NumPy backend. This class can be directly
     used to construct four dimensional NumPy momentum vectors. For three dimensional
@@ -1785,6 +2022,15 @@ class MomentumNumpy4D(LorentzMomentum, VectorNumpy4D):  # type: ignore[misc]
         MomentumNumpy4D([(1.1, 2.1, 3.1, 4.1), (1.2, 2.2, 3.2, 4.2), (1.3, 2.3, 3.3, 4.3),
                          (1.4, 2.4, 3.4, 4.4), (1.5, 2.5, 3.5, 4.5)],
                         dtype=[('x', '<f8'), ('y', '<f8'), ('z', '<f8'), ('t', '<f8')])
+
+        >>> import numpy as np
+        >>> import vector
+        >>> arr = np.array([(1.1, 2.1, 3.1, 4.1), (1.2, 2.2, 3.2, 4.2), (1.3, 2.3, 3.3, 4.3), (1.4, 2.4, 3.4, 4.4), (1.5, 2.5, 3.5, 4.5)],
+        ...               dtype=[('px', float), ('py', float), ('pz', float), ('t', float)])
+        >>> arr.view(vector.MomentumNumpy4D)
+        MomentumNumpy4D([(1.1, 2.1, 3.1, 4.1), (1.2, 2.2, 3.2, 4.2), (1.3, 2.3, 3.3, 4.3),
+                         (1.4, 2.4, 3.4, 4.4), (1.5, 2.5, 3.5, 4.5)],
+                        dtype=[('x', '<f8'), ('y', '<f8'), ('z', '<f8'), ('t', '<f8')])
     """
 
     ObjectClass = vector.backends.object.MomentumObject4D
@@ -1924,28 +2170,34 @@ VectorNumpy2D.ProjectionClass2D = VectorNumpy2D
 VectorNumpy2D.ProjectionClass3D = VectorNumpy3D
 VectorNumpy2D.ProjectionClass4D = VectorNumpy4D
 VectorNumpy2D.GenericClass = VectorNumpy2D
+VectorNumpy2D.MomentumClass = MomentumNumpy2D
 
 MomentumNumpy2D.ProjectionClass2D = MomentumNumpy2D
 MomentumNumpy2D.ProjectionClass3D = MomentumNumpy3D
 MomentumNumpy2D.ProjectionClass4D = MomentumNumpy4D
 MomentumNumpy2D.GenericClass = VectorNumpy2D
+MomentumNumpy2D.MomentumClass = MomentumNumpy2D
 
 VectorNumpy3D.ProjectionClass2D = VectorNumpy2D
 VectorNumpy3D.ProjectionClass3D = VectorNumpy3D
 VectorNumpy3D.ProjectionClass4D = VectorNumpy4D
 VectorNumpy3D.GenericClass = VectorNumpy3D
+VectorNumpy3D.MomentumClass = MomentumNumpy3D
 
 MomentumNumpy3D.ProjectionClass2D = MomentumNumpy2D
 MomentumNumpy3D.ProjectionClass3D = MomentumNumpy3D
 MomentumNumpy3D.ProjectionClass4D = MomentumNumpy4D
 MomentumNumpy3D.GenericClass = VectorNumpy3D
+MomentumNumpy3D.MomentumClass = MomentumNumpy3D
 
 VectorNumpy4D.ProjectionClass2D = VectorNumpy2D
 VectorNumpy4D.ProjectionClass3D = VectorNumpy3D
 VectorNumpy4D.ProjectionClass4D = VectorNumpy4D
 VectorNumpy4D.GenericClass = VectorNumpy4D
+VectorNumpy4D.MomentumClass = MomentumNumpy4D
 
 MomentumNumpy4D.ProjectionClass2D = MomentumNumpy2D
 MomentumNumpy4D.ProjectionClass3D = MomentumNumpy3D
 MomentumNumpy4D.ProjectionClass4D = MomentumNumpy4D
 MomentumNumpy4D.GenericClass = VectorNumpy4D
+MomentumNumpy4D.MomentumClass = MomentumNumpy4D
