@@ -1,4 +1,4 @@
-# Copyright (c) 2019-2023, Jonas Eschle, Jim Pivarski, Eduardo Rodrigues, and Henry Schreiner.
+# Copyright (c) 2019-2024, Jonas Eschle, Jim Pivarski, Eduardo Rodrigues, and Henry Schreiner.
 #
 # Distributed under the 3-clause BSD license, see accompanying file LICENSE
 # or https://github.com/scikit-hep/vector for details.
@@ -11,43 +11,6 @@ import pytest
 import vector
 
 
-def test_dimension_conversion():
-    # 2D -> 3D
-    vec = vector.VectorObject2D(x=1, y=2)
-    assert vec.to_Vector3D(z=1).z == 1
-    assert vec.to_Vector3D(eta=1).eta == 1
-    assert vec.to_Vector3D(theta=1).theta == 1
-
-    assert vec.to_Vector3D(z=1).x == vec.x
-    assert vec.to_Vector3D(z=1).y == vec.y
-
-    # 2D -> 4D
-    assert vec.to_Vector4D(z=1, t=1).z == 1
-    assert vec.to_Vector4D(z=1, t=1).t == 1
-    assert vec.to_Vector4D(eta=1, t=1).eta == 1
-    assert vec.to_Vector4D(eta=1, t=1).t == 1
-    assert vec.to_Vector4D(theta=1, t=1).theta == 1
-    assert vec.to_Vector4D(theta=1, t=1).t == 1
-    assert vec.to_Vector4D(z=1, tau=1).z == 1
-    assert vec.to_Vector4D(z=1, tau=1).tau == 1
-    assert vec.to_Vector4D(eta=1, tau=1).eta == 1
-    assert vec.to_Vector4D(eta=1, tau=1).tau == 1
-    assert vec.to_Vector4D(theta=1, tau=1).theta == 1
-    assert vec.to_Vector4D(theta=1, tau=1).tau == 1
-
-    assert vec.to_Vector4D(z=1, t=1).x == vec.x
-    assert vec.to_Vector4D(z=1, t=1).y == vec.y
-
-    # 3D -> 4D
-    vec = vector.VectorObject3D(x=1, y=2, z=3)
-    assert vec.to_Vector4D(t=1).t == 1
-    assert vec.to_Vector4D(tau=1).tau == 1
-
-    assert vec.to_Vector4D(t=1).x == vec.x
-    assert vec.to_Vector4D(t=1).y == vec.y
-    assert vec.to_Vector4D(t=1).z == vec.z
-
-
 def test_constructors_2D():
     vec = vector.VectorObject2D(x=1, y=2)
     assert vec.x == 1
@@ -257,41 +220,3 @@ def test_array_casting():
 
     with pytest.raises(TypeError):
         vector.obj(x=1, y=False)
-
-
-def test_demotion():
-    v1 = vector.obj(x=0.1, y=0.2)
-    v2 = vector.obj(x=1, y=2, z=3)
-    v3 = vector.obj(x=10, y=20, z=30, t=40)
-
-    # order should not matter
-    assert v1 + v2 == vector.obj(x=1.1, y=2.2)
-    assert v2 + v1 == vector.obj(x=1.1, y=2.2)
-    assert v1 + v3 == vector.obj(x=10.1, y=20.2)
-    assert v3 + v1 == vector.obj(x=10.1, y=20.2)
-    assert v2 + v3 == vector.obj(x=11, y=22, z=33)
-    assert v3 + v2 == vector.obj(x=11, y=22, z=33)
-
-    v1 = vector.obj(px=0.1, py=0.2)
-    v2 = vector.obj(px=1, py=2, pz=3)
-    v3 = vector.obj(px=10, py=20, pz=30, t=40)
-
-    # order should not matter
-    assert v1 + v2 == vector.obj(px=1.1, py=2.2)
-    assert v2 + v1 == vector.obj(px=1.1, py=2.2)
-    assert v1 + v3 == vector.obj(px=10.1, py=20.2)
-    assert v3 + v1 == vector.obj(px=10.1, py=20.2)
-    assert v2 + v3 == vector.obj(px=11, py=22, pz=33)
-    assert v3 + v2 == vector.obj(px=11, py=22, pz=33)
-
-    v1 = vector.obj(px=0.1, py=0.2)
-    v2 = vector.obj(x=1, y=2, z=3)
-    v3 = vector.obj(px=10, py=20, pz=30, t=40)
-
-    # momentum + generic = generic
-    assert v1 + v2 == vector.obj(x=1.1, y=2.2)
-    assert v2 + v1 == vector.obj(x=1.1, y=2.2)
-    assert v1 + v3 == vector.obj(px=10.1, py=20.2)
-    assert v3 + v1 == vector.obj(px=10.1, py=20.2)
-    assert v2 + v3 == vector.obj(x=11, y=22, z=33)
-    assert v3 + v2 == vector.obj(x=11, y=22, z=33)
