@@ -1,4 +1,4 @@
-# Copyright (c) 2019-2023, Jonas Eschle, Jim Pivarski, Eduardo Rodrigues, and Henry Schreiner.
+# Copyright (c) 2019-2024, Jonas Eschle, Jim Pivarski, Eduardo Rodrigues, and Henry Schreiner.
 #
 # Distributed under the 3-clause BSD license, see accompanying file LICENSE
 # or https://github.com/scikit-hep/vector for details.
@@ -26,6 +26,10 @@ def test_eq():
     assert not (v1 == a1).all()
     assert (a1 == v1).any()
     assert not (a1 == v1).all()
+    with pytest.raises(TypeError):
+        v1.equal(v2.to_Vector3D())
+    with pytest.raises(TypeError):
+        a1.equal(a2.to_Vector3D())
 
 
 def test_ne():
@@ -37,6 +41,10 @@ def test_ne():
     assert not (v1 != a1).all()
     assert (a1 != v1).any()
     assert not (a1 != v1).all()
+    with pytest.raises(TypeError):
+        v1.not_equal(v2.to_Vector3D())
+    with pytest.raises(TypeError):
+        a1.not_equal(a2.to_Vector3D())
 
 
 def test_abs():
@@ -49,10 +57,15 @@ def test_abs():
 
 def test_add():
     assert v1 + v2 == vector.obj(x=11, y=25)
+    assert v1 + v2.to_Vector3D().like(v1) == vector.obj(x=11, y=25)
     assert numpy.allclose(
         a1 + a2,
         vector.array({"x": [11, 102, 1003, 10004], "y": [25, 206, 2007, 20008]}),
     )
+    assert numpy.allclose(
+        a1 + a2.to_Vector3D().like(a1),
+        vector.array({"x": [11, 102, 1003, 10004], "y": [25, 206, 2007, 20008]}),
+    )
     assert numpy.allclose(
         v1 + a2,
         vector.array({"x": [11, 101, 1001, 10001], "y": [25, 205, 2005, 20005]}),
@@ -65,6 +78,10 @@ def test_add():
         v1 + 5
     with pytest.raises(TypeError):
         5 + v1
+    with pytest.raises(TypeError):
+        v1 + v2.to_Vector3D()
+    with pytest.raises(TypeError):
+        a1 + a2.to_Vector3D()
 
 
 def test_sub():
@@ -85,6 +102,10 @@ def test_sub():
         v1 - 5
     with pytest.raises(TypeError):
         5 - v1
+    with pytest.raises(TypeError):
+        v1 - v2.to_Vector3D()
+    with pytest.raises(TypeError):
+        a1 - a2.to_Vector3D()
 
 
 def test_mul():
