@@ -1,4 +1,4 @@
-# Copyright (c) 2019-2023, Jonas Eschle, Jim Pivarski, Eduardo Rodrigues, and Henry Schreiner.
+# Copyright (c) 2019-2024, Jonas Eschle, Jim Pivarski, Eduardo Rodrigues, and Henry Schreiner.
 #
 # Distributed under the 3-clause BSD license, see accompanying file LICENSE
 # or https://github.com/scikit-hep/vector for details.
@@ -17,7 +17,7 @@ def test():
         longitudinal=vector.backends.object.LongitudinalObjectZ(3),
         temporal=vector.backends.object.TemporalObjectT(4),
     )
-    p4 = vector.backends.object.VectorObject4D(
+    p4 = vector.backends.object.MomentumObject4D(
         azimuthal=vector.backends.object.AzimuthalObjectXY(5, 6),
         longitudinal=vector.backends.object.LongitudinalObjectZ(7),
         temporal=vector.backends.object.TemporalObjectT(15),
